@@ -24,16 +24,37 @@ void Configurator::initMe(QApplication *pApp)
 	bool bState = false;
 	m_pNewProcess = NULL;
 	m_iCurrentStep = 0;
+	m_qtTime.start();
 	m_iTotalSteps = getCompileSteps();
 	progressBarCompile->setTotalSteps ( TOTAL_PROGRESS );
 
 	// For now we only have included propper support for xine-lib
 	QString qsLib("libxine.so");
 	if (!checkLibraryExists (qsLib))
-		radioVideoXine->setEnabled(false);
-	qsLib = QString ("libdha.so");
-	if (!checkLibraryExists (qsLib))
-		radioVideoMPlayer->setEnabled(false);
+		checkVideoXine->setEnabled(false);
+	// disable VLC support for now.
+//	qsLib = QString ("libvlc.so");
+//	qsLib = QString ("libvlc.a");
+//	if (!checkLibraryExists (qsLib))
+		checkVideoVLC->setEnabled(false);
+	qsLib = QString ("mplayer");
+	system ((const char *)QString ("which %1 > /tmp/out.txt 2>/dev/null").arg(qsLib));
+	QFileInfo fileInfo("/tmp/out.txt");
+	// Okay we can not find it, so we wont bother asking the user ...
+	if (fileInfo.size() < 5)
+		checkVideoMPlayer->setEnabled(false);
+
+	if (!(checkVideoXine->isEnabled() || checkVideoMPlayer->isEnabled() || checkVideoVLC->isEnabled() ))	{
+		// Okay did not find any media player installed so we choose MPlayer per default.
+		checkVideoMPlayer->setEnabled(true);
+		checkVideoMPlayer->setChecked(true);
+	}
+	if (checkVideoXine->isEnabled())
+		checkVideoXine->setChecked(true);
+	if (checkVideoMPlayer->isEnabled())
+		checkVideoMPlayer->setChecked(true);
+	if (checkVideoVLC->isEnabled())
+		checkVideoVLC->setChecked(true);
 
 	// Last we set the lineEdits to reflect the current environment variables.
 	QString qsInstallDir (getenv("PREFIX"));
@@ -64,7 +85,7 @@ QString Configurator::findGuiSU()
 	QFileInfo fileInfo("/tmp/out.txt");
 	for (t=0;t<3;t++)	{
 		// the next check is to see if we can find kdesu
-		system ((const char *)QString ("which %1 > /tmp/out.txt").arg(arraySUs[t]));
+		system ((const char *)QString ("which %1 > /tmp/out.txt 2>/dev/null").arg(arraySUs[t]));
 		fileInfo.setFile("/tmp/out.txt");
 		// Okay we cna not find it, so we wont bother asking the user ...
 		if (fileInfo.size() > 4)	{
@@ -119,6 +140,7 @@ bool Configurator::checkLibraryExists(QString &libName)
 
 void Configurator::slotCompile()
 {
+	QCursor myCursor (QCursor::WaitCursor);
 	uint t;
 	m_iTotalSteps = getCompileSteps();
 	tabWidget2->setCurrentPage(2);
@@ -147,10 +169,15 @@ void Configurator::slotCompile()
 
 	if (!editLDLibraryPath->text().isEmpty())
 		listEnv.append (QString("LD_LIBRARY_PATH=%1").arg(editLDLibraryPath->text()));
-	if (radioVideoXine->isOn())
-		 listEnv.append ("VIDEO_LIB=xine");
-	else if (radioVideoMPlayer->isOn())
-		 listEnv.append ("VIDEO_LIB=mplayer");
+	if (checkVideoXine->isOn())
+		 listEnv.append ("WITH_XINE_SUPPORT=1");
+	if (checkVideoMPlayer->isOn())
+		 listEnv.append ("WITH_MPLAYER_SUPPORT=1");
+	if (checkVideoVLC->isOn())
+		 listEnv.append ("WITH_VLC_SUPPORT=1");
+
+	if ( !checkVideoXine->isOn() && !checkVideoMPlayer->isOn() && !checkVideoVLC->isOn() )
+		 listEnv.append ("WITH_MPLAYER_SUPPORT=1");
 
 	QString qtLib1 ("libqt-mt.so");
 	QString qtLib2 ("libqt.so");
@@ -174,6 +201,9 @@ void Configurator::slotCompile()
 
 	// qdvdauthor.pro needs those files to physically be there ... Go figure !
 	system ("touch ../bin/qdvdauthor ../bin/qslideshow ../bin/qplayer");
+	// Next we should remove the Makefile's so we build with new media engine - support.
+	if (hasMediaEngineSelectionChanged())
+		system ("rm ../qdvdauthor/Makefile ../qdvdauthor/qplayer/Makefile ../qdvdauthor/qslideshow/Makefile");
 
 	m_pNewProcess->setWorkingDirectory (QDir ("../"));
 	// And here we generate the make file and compile the application.
@@ -184,6 +214,7 @@ void Configurator::slotCompile()
 	while (m_pNewProcess->isRunning())
 		sleep (1);
 	m_pNewProcess->clearArguments();
+	QApplication::setOverrideCursor (myCursor);
 
 	m_pNewProcess->addArgument (QString("make"));
 	if (!editMakeOptions->text().isEmpty())	{
@@ -194,6 +225,50 @@ void Configurator::slotCompile()
 	}
 
 	m_pNewProcess->start ();
+	m_qtTime.restart();
+}
+
+bool Configurator::hasMediaEngineSelectionChanged()
+{
+	// Here we check if the selection has changed. Meaning that qplayer/MEDIA_CONFIG.h has changed.
+	bool bHasChanged = true;
+	bool bMPlayerSupport, bXineSupport, bVLCSupport;
+	QString qsLine;
+	QString qsFileName;
+
+	qsFileName = QString ("../qdvdauthor/Makefile");
+	QFileInfo fileInfo(qsFileName);
+	if (!fileInfo.exists())
+		return false;
+
+	qsFileName = QString ("../qdvdauthor/qplayer/MEDIA_CONFIG.h");
+	QFile file( qsFileName );
+	bMPlayerSupport = bXineSupport = bVLCSupport = false;
+	// First we pars the config file.
+	if (file.exists())	{
+		if ( file.open( IO_ReadOnly ) ) {
+			bHasChanged = false;
+			while ( !file.atEnd() ) {
+				file.readLine (qsLine, 1000);
+				// parse for MPLAYER_SUPPORT, XINE_SUPPORT, or VLC_SUPPORT
+				if (qsLine.find("MPLAYER_SUPPORT") > -1 )
+					bMPlayerSupport = true;
+				else if (qsLine.find("XINE_SUPPORT") > -1 )
+					bXineSupport = true;
+				else if (qsLine.find("VLC_SUPPORT") > -1 )
+					bVLCSupport = true;
+			}
+        }
+        file.close();
+	}
+	// next we determine if the selection has changed.
+	if ( bMPlayerSupport != (checkVideoMPlayer->isOn()) )
+		bHasChanged = true;
+	if ( bXineSupport != (checkVideoXine->isOn()) )
+		bHasChanged = true;
+	if ( bVLCSupport != (checkVideoVLC->isOn()) )
+		bHasChanged = true;
+	return bHasChanged;
 }
 
 void Configurator::slotReadFromStdout()
@@ -202,8 +277,10 @@ void Configurator::slotReadFromStdout()
 //static int iCounter =0;
 //iCounter ++;
 //printf ("<%d>\n", iCounter);
+//	QString stdOut = QString("%1 > ").arg(iCounter);
+//	stdOut += m_pNewProcess->readStdout();
 	QString stdOut = m_pNewProcess->readStdout();
-	if (stdOut.length() < 2)
+	if (stdOut.length() < 5)
 		return;
 	textOutput->append (stdOut);
 	// and here we take care of the progress bar.
@@ -212,6 +289,18 @@ void Configurator::slotReadFromStdout()
 		m_iCurrentStep = m_iTotalSteps;
 	float fProgress = ((float)(m_iCurrentStep) / (float)(m_iTotalSteps) ) * TOTAL_PROGRESS;
 	progressBarCompile->setProgress ( (int)fProgress );
+
+	uint iElapsedSeconds = (int) ((float)m_qtTime.elapsed()/1000.0);
+	QString qsTimeString ("0 sec");
+	if (iElapsedSeconds < 60 )
+		qsTimeString = QString ("%1 sec").arg(iElapsedSeconds);
+	else	{
+		uint iMinutes, iSeconds;
+		iMinutes = (uint)(iElapsedSeconds / 60.0);
+		iSeconds = iElapsedSeconds - 60*iMinutes;
+		qsTimeString.sprintf("%02d:%02d", iMinutes, iSeconds);
+	}
+	setCaption (tr("Configurator for qdvdautor <%1>").arg(qsTimeString));
 }
 
 void Configurator::slotReadFromStderr()
@@ -248,60 +337,98 @@ void Configurator::slotProcessExited()
 		
 	buttonExecute->setEnabled( bState );
 	if (bState)	{
+		QApplication::restoreOverrideCursor ();
+
 		// the next check is to see if we can find kdesu
 		if (findGuiSU().isEmpty())
 			bState = false;
 	}
 	buttonInstall->setEnabled( bState );
+
+	// Exactly the same handling of the title as under slotReadFromStdout
+	uint iElapsedSeconds = (int) ((float)m_qtTime.elapsed()/1000.0);
+	QString qsTimeString ("0 sec");
+	if (iElapsedSeconds < 60 )
+		qsTimeString = QString ("%1 sec").arg(iElapsedSeconds);
+	else	{
+		uint iMinutes, iSeconds;
+		iMinutes = (uint)(iElapsedSeconds / 60.0);
+		iSeconds = iElapsedSeconds - 60*iMinutes;
+		qsTimeString.sprintf("%02d:%02d", iMinutes, iSeconds);
+	}
+
+	setCaption (tr("Configurator for qdvdautor <%1>").arg(qsTimeString));
 }
 
 int Configurator::getCompileSteps ()
 {
-	int iStepCounter;
-	// This function checks how many steps the compilation process approximately has.
-	QDir theCompileDir ("../qdvdauthor");
-// 	3 * *.ui + *.cpp * *.cpp + *.ui * 2*iamge + link - .obj/*
-//	3*4 + 6 + 6 + 4 + 2 + 1 - 0 = 31;
-	QDir theDir ("../qdvdauthor");
+	int iStepCounter, t;
+	int iUIFiles, iHeaderFiles, iObjectHeader ,iExtra;
 	QStringList fileList;
+	// This function checks how many steps the compilation process approximately has.
+//	QStringList fileList;
+// 	5 *.ui + 2 *.h (object) + .h(normal) - .ui/* -.moc/* -.obj/*
+	QString arrayDirs[7];
+	// Here we init the directory array
+	arrayDirs[0] = QString ("../qdvdauthor");
+	arrayDirs[1] = QString ("../qdvdauthor/qplayer");
+	arrayDirs[2] = QString ("../qdvdauthor/qplayer/engines");
+	arrayDirs[3] = QString ("../qdvdauthor/qslideshow");
+	arrayDirs[4] = QString ("../qdvdauthor/.ui");
+	arrayDirs[5] = QString ("../qdvdauthor/.moc");
+	arrayDirs[6] = QString ("../qdvdauthor/.obj");
+	// Next we change into the soiurce directory
+	QDir theDir ("../qdvdauthor");
+
+	iUIFiles = iHeaderFiles = iObjectHeader = iExtra = 0;
+	// obtain with : `find . -name "*.h" -exec grep Q_OBJECT {} \; -print | grep -v Q_OBJECT | grep -v "/.ui/" | wc -l`
+	iObjectHeader = 39;
+	// obtain through trial and error
+	iExtra        = 19;
+	// now we get the rest of the information ...
 	theDir.setNameFilter("*.ui");
-	fileList = theDir.entryList();
-	iStepCounter = fileList.count() * 4;
+	for (t=0;t<4;t++)	{
+		theDir.setPath(arrayDirs[t]);
+		fileList = theDir.entryList();
+		iUIFiles += fileList.count();
+		if (t>0)	// the first entry we dont want to change directories
+			theDir.setPath("..");
+	}
+	iUIFiles *= 5;
+	theDir.setNameFilter("*.h");
+	for (t=0;t<4;t++)	{
+		theDir.setPath(arrayDirs[t]);
+		fileList = theDir.entryList();
+		iHeaderFiles += fileList.count();
+		if (t>0)	// the first entry we dont want to change directories
+			theDir.setPath("..");
+	}
+	// finally we adjust for object headers count.
+	iObjectHeader *= 2;
+	// Here we calculate the total steps required
+	iStepCounter = iUIFiles + iHeaderFiles + iObjectHeader + iExtra;
+//printf ("<%d> = <%d><%d><%d><%d>\n", iStepCounter, iUIFiles, iHeaderFiles, iObjectHeader, iExtra);
+	// Next is to take into account if the user disabled some MediaEngines ...
+	if (checkVideoXine->isOn())
+		 iStepCounter -= 6;
+	if (checkVideoMPlayer->isOn())
+		 iStepCounter -= 6;
+	if (checkVideoVLC->isOn())
+		 iStepCounter -= 6;
 
-	theDir.setNameFilter("*.cpp");
-	fileList = theDir.entryList();
-	iStepCounter += fileList.count() * 3;
-
-	theDir.setPath ("../qdvdauthor/.obj");
-	theDir.setNameFilter("*.o");
-	fileList = theDir.entryList();
-	iStepCounter -= fileList.count();
-	iStepCounter += 3;
-
-	// The slideshow sub-directory
-	theDir.setPath ("../qslideshow");
-	theDir.setNameFilter("*.ui");
-	fileList = theDir.entryList();
-	iStepCounter += fileList.count() * 4;
-
-	theDir.setNameFilter("*.cpp");
-	fileList = theDir.entryList();
-	iStepCounter += fileList.count() * 5;
-
-	// The QXine sub-directory
-	theDir.setPath ("../qplayer");
-	theDir.setNameFilter("*.ui");
-	fileList = theDir.entryList();
-	iStepCounter += fileList.count() * 4;
-
-	theDir.setNameFilter("*.cpp");
-	fileList = theDir.entryList();
-	iStepCounter += fileList.count() * 5;
+	theDir.setNameFilter("*");
+	for (t=4;t<7;t++)	{
+		theDir.setPath(arrayDirs[t]);
+		fileList = theDir.entryList();
+		iStepCounter -= fileList.count();
+		theDir.setPath("..");
+	}
 
+	// and then we substract the files / objects already created.
 	theDir.setPath ("..");
-
 	// Okay, for now manually until I found a good algol ...
-	iStepCounter = 214;
+//	iStepCounter = 270;	// MPlayer and Xine support
+//	iStepCounter = 276;	// VLC, MPlayer and Xine support
 	return iStepCounter;
 }
 
@@ -389,12 +516,14 @@ void Configurator::slotInstall()
 	if (qsGuiSU.isEmpty())
 		bCanWriteToInstallDir = true;
 
-	m_iTotalSteps = 1;
+	m_iTotalSteps  = 24;
+	m_iCurrentStep = 0;
 	tabWidget2->setCurrentPage(2);
 	progressBarCompile->setProgress (0);
 
 	m_pNewProcess  = new QProcess ( this );
 	connect( m_pNewProcess, SIGNAL(readyReadStdout()), this, SLOT(slotReadFromStdout()) );
+	connect( m_pNewProcess, SIGNAL(processExited()), this, SLOT(slotProcessExited()) );
 	QStringList listEnv;
 
 	// Here we print the newly added environment variables.
@@ -464,40 +593,62 @@ void Configurator::slotAboutToQuit()
 
 void Configurator::slotInfoXine()
 {
-	if (radioVideoXine->isEnabled ())
+	if (checkVideoXine->isEnabled ())
 		QMessageBox::information (NULL, QString ("Xine Library"),
 		QString ("This library is installed and should work for all purposes.\n"
-			"You can also install and use the MPlayer libraries \n"
-			"and use this library instead of xine to display the media streams.\n"),
+			"You can also install and use MPlayer or the VLC libraries\n"
+			"and use one of them instead of xine to display the media streams.\n\n"
+
+			"Please note that each media player backend has advantages and disadvantages\n"),
 			QMessageBox::Ok ,  QMessageBox::NoButton);
 	else
 		QMessageBox::warning (NULL, QString ("Xine not installed."),
 		QString ("Attention, xine is not installed, thus you \n"
-			"should choose MPlayer.\n\n"),
+			"should choose MPlayer or VLC instead.\n\n"
+
+			"http://www.xinehq.de\n"),
 			QMessageBox::Ok ,  QMessageBox::NoButton);
 }
 
 void Configurator::slotInfoMPlayer()
 {
-	if (radioVideoMPlayer->isEnabled ())
-		QMessageBox::information (NULL, QString ("MPLayer library"),
-		QString ("This functionality is not yet incorporated.\n"
-			"Any takers on this one ?\n\n"
-			),
+	if (checkVideoMPlayer->isEnabled ())
+		QMessageBox::information (NULL, QString ("MPLayer executable"),
+		QString ("This player is installed and should work for all purposes.\n"
+			"You can also install xine-lib or vlc-lib and compile 'Q' DVD-Author\n"
+			"to use this library instead.\n\n"),
 			QMessageBox::Ok ,  QMessageBox::NoButton);
-/*		QMessageBox::information (NULL, QString ("MPLayer library"),
-		QString ("This library is installed and should work for all purposes.\n"
-			"You can also install xine-lib and compile 'Q' DVD-Author\n"
-			"to use this library instead.\n\n"
-			),
-			QMessageBox::Ok ,  QMessageBox::NoButton);
-*/	else
+	else
 		QMessageBox::warning (NULL, QString ("MPlayer not installed."),
 		QString ("Attention, MPlayer is not installed, thus you \n"
-			"should choose xine instead.\n\n"),
+			"should choose xine instead.\n\n"
+			
+			"http://www.mplayerhq.hu\n"),
+			QMessageBox::Ok ,  QMessageBox::NoButton);
+}
+
+void Configurator::slotInfoVLC()
+{
+	if (checkVideoVLC->isEnabled ())
+		QMessageBox::information (NULL, QString ("VLC library"),
+		QString ("This library is installed and should work for all purposes.\n"
+			"You can also install xine-lib or MPlayer and compile 'Q' DVD-Author\n"
+			"to use this library instead.\n\n" 
+			),
+			QMessageBox::Ok ,  QMessageBox::NoButton);
+	else
+		QMessageBox::warning (NULL, QString ("VLC not installed."),
+		QString ("Attention, VLC is not installed, thus you \n"
+			"should choose xine instead.\n\n"
+			
+			"Note: Currently the videolan - project does not release a libvlc.so\n"
+			"thus VLC support is currently disabled.\n\n"
+
+			"If VLC is installed please ensure that the path is\n"
+			"in /etc/ld.so.conf.\n\n"
+			
+			"http://www.videolan.orrg\n"),
 			QMessageBox::Ok ,  QMessageBox::NoButton);
 }
 
 
-
-
