@@ -61,6 +61,7 @@ public:
 	virtual ~ButtonObject();
 	virtual void drawContents         (QPainter *);
 	virtual void drawContents         (QPainter *, uint);
+	virtual void drawContents         (QPainter *, int, int);
 	virtual bool mouseMoveEvent       (QMouseEvent *);
 	virtual bool mousePressEvent      (QMouseEvent *);
 	virtual bool mouseReleaseEvent    (QMouseEvent *);
@@ -92,29 +93,31 @@ public:
 	void setSourceFileEntry (SourceFileEntry *);
 
 	void deleteMasks();
-	bool ButtonObject::readObjects (QDomNode &, MenuPreview *);
+	bool readObjects (QDomNode &, MenuPreview *);
 	QString &sourceDisplayName ();
 
 	void replaceColor (QColor, QColor);
 
 protected:
 	void clear ();
+	virtual AnimationAttribute *getSpecificAttributes (long, QString);
+
 
 signals:
-	void signalDeleteMe  (MenuObject *);
-	void signalUnbuttonMe(ButtonObject *);
+	void signalUnbuttonMe        (ButtonObject *);
 	void signalCreateButtonDialog(ButtonObject *);
 
 public slots:
-	virtual void slotEdit();
+	virtual void slotEdit    ();
 	virtual void slotUnbutton();
-	virtual void slotDelete();
+	virtual void slotMoveable();
 	virtual void slotAddFrame();
 	virtual void slotAddImage();
 	virtual void slotAddMovie();
 
 protected:
 	int     m_iButtonState;
+	bool    m_bMoveable;
 	QString m_qsAction;	// the action to take ...
 	QString m_qsUp;
 	QString m_qsDown;
