@@ -14,7 +14,6 @@
 #define BUTTONPREVIEW_H
 
 #include <qlabel.h>
-//#include <qvaluelist.h>
 #include <qptrlist.h>
 #include <qpixmap.h>
 
@@ -23,6 +22,9 @@
 class QDomNode;
 class QDomElement;
 
+class UndoBuffer;
+class CDVDMenuInterface;
+
 class ButtonPreview : public QLabel
 {
 	Q_OBJECT
@@ -30,35 +32,47 @@ public:
 	 ButtonPreview (QWidget * parent, const char * name = 0, WFlags f = 0 );
 	~ButtonPreview ();
 
-	void toTop (MenuObject *);
+	void         toTop            (MenuObject *);
+	void         setViewport      (QRect &);
+	UndoBuffer  *undoBuffer       ();
+	MenuObject  *childContains    (QPoint &);
+	MenuObject  *menuObject       (uint);
+	uint         objectCount      ();
+	void         updatePixmap     ();
+	bool         removeObject     (MenuObject *);
+	void         addMenuObject    (MenuObject *);
+	QPixmap     &renderMenu       (CDVDMenuInterface *, long, long);
+	void fitDVDMenuBackground     (QPixmap  *, int, int, QSize, int, int);
 
-	void addMenuObject(MenuObject *);
-	void setViewport(QRect &);
-	MenuObject *childContains (QPoint &);
-	MenuObject *menuObject (uint);
-	uint objectCount();
-	void updatePixmap ();
-	void setCurrentPath(QString &);
+public slots:
+	virtual void slotDeleteObject (MenuObject *);
+	virtual void setPixmap        (const QPixmap &);
+	virtual void slotMoveOnStack  (MenuObject *, int);
 	
-public slots:	
-	virtual void slotDeleteObject   (MenuObject *);
-	virtual void setPixmap (const QPixmap &);
+signals:
+	 void signalRenderProgress    (float);
 
 protected:
-	virtual void mousePressEvent		(QMouseEvent *);
-	virtual void mouseReleaseEvent		(QMouseEvent *);
-	virtual void mouseDoubleClickEvent	(QMouseEvent *);
+	virtual void mousePressEvent	   (QMouseEvent *);
+	virtual void mouseReleaseEvent	   (QMouseEvent *);
+	virtual void mouseDoubleClickEvent (QMouseEvent *);
 
-	virtual void drawContents (QPainter *);
+	virtual void drawContents     (QPainter *);
+
+private:
+	void drawVisibleRegion        (QPainter *);
 
 protected:
+	// Here we have the undo buffer ...
+	UndoBuffer *m_pUndoBuffer;
+
 	QPtrList<MenuObject>	 m_listMenuObjects;
 	QRect m_rectViewport;		// This is the viewport set in drawContents()
 	QPixmap m_backgroundPixmap;
 	MenuObject *m_pActiveObject;
 	// tells the process to skip further handling of the MouseEvents since they were already taken care of.
 	bool m_bMouseEventDone;
-	QString m_qsCurrentPath;
+	bool m_bDrawVisibleRegion;
 };
 
 // I NEVER rely on my own memory, as I have determined that is not only faulty, but actively working against me.
