@@ -140,7 +140,7 @@ void ColorToolBar::modifyColor(QColor theColor, uint iWhichColor, void *pMenu)
 		if (iWhichColor == SELECTED_MASK)
 			qsWhichColor = QString ("Selected");
 
-		if (QMessageBox::question ( this, tr("Change all colors ?"), tr("This modification will change will affect all %1 colors.\n"
+		if (QMessageBox::information ( this, tr("Change all colors ?"), tr("This modification will change will affect all %1 colors.\n"
 			"Do you want to proceed ?").arg(qsWhichColor), QMessageBox::Yes, QMessageBox::No ) == QMessageBox::No)
 			return;
 	}
