@@ -1,5 +1,5 @@
 /****************************************************************************
-** DialogTextFont class
+** DialogButton class
 **
 ** Created: Wed Feb 26 22:48:00 2004
 **      by: Varol Okan using Kate
@@ -23,6 +23,7 @@
 #include <qlayout.h>
 #include <qframe.h>
 #include <qfileinfo.h>
+#include <qmessagebox.h>
 
 #include "global.h"
 #include "dialogbutton.h"
@@ -33,6 +34,7 @@
 
 #define BUTTON_BASIC    "<<< Basic"
 #define BUTTON_ADVANCED "Advanced >>>"
+#define MANUAL_CHANGE   255, 180, 60
 
 DialogButton::DialogButton(QWidget * parent, const char * name, WFlags f)
 	: uiDialogButton (parent, name, f)
@@ -40,6 +42,7 @@ DialogButton::DialogButton(QWidget * parent, const char * name, WFlags f)
 	// Standard is set to false. This indicates that we create a button as
 	// opposed to modify an existing one.
 	m_bButtonCreation = false;
+	m_bAutomatic = false;
 }
 
 DialogButton::~DialogButton()
@@ -133,6 +136,7 @@ void DialogButton::initMe(ButtonObject *pButton, QObject *pView)
 	connect (m_pButtonHelpGoto,   SIGNAL(clicked()), this, SLOT(slotHelpGoto()));
 	connect (m_pButtonHelp,       SIGNAL(clicked()), this, SLOT(slotHelp()));
 	connect (m_pTabWidget,        SIGNAL(currentChanged(QWidget *)), this, SLOT(slotTabChanged(QWidget *)));
+	connect (m_pEditAction,       SIGNAL(textChanged(const QString &)), this, SLOT(slotEditActionChanged(const QString &)));
 
 	connect (m_pButtonOkay,       SIGNAL(clicked()), this, SLOT(slotOkay ()));
 	connect (m_pButtonCancel,     SIGNAL(clicked()), this, SLOT(slotCancel()));
@@ -150,33 +154,33 @@ void DialogButton::initNext()
 
 	// First we build the available choices ...
 	QComboBox *comboArray[4];
-	comboArray[0] = m_pComboUp;
-	comboArray[1] = m_pComboDown;
-	comboArray[2] = m_pComboRight;
-	comboArray[3] = m_pComboLeft;
+	int intArray[4];
+	comboArray[0] = m_pComboUp;	intArray[0] = NEXT_BUTTON_UP;
+	comboArray[1] = m_pComboDown;	intArray[1] = NEXT_BUTTON_DOWN;
+	comboArray[2] = m_pComboRight;	intArray[2] = NEXT_BUTTON_RIGHT;
+	comboArray[3] = m_pComboLeft;	intArray[3] = NEXT_BUTTON_LEFT;
 	uint t, i;
 	for (t=0;t<4;t++)	{
 		comboArray[t]->clear();
 		// The main menu (bien sur)
 //		comboArray[t]->insertItem(QString("vmgm"));
-		comboArray[t]->insertItem(QString(""));
+		comboArray[t]->insertItem(QString("-- default --"));
 		// Next we should include all sub-menus ...
 		for (i=0;i<m_listSubMenus.count();i++)
 			comboArray[t]->insertItem(m_listSubMenus[i]);
 		// and also all available Buttons for the current menu
 		for (i=0;i<m_listMenuButtons.count();i++)
 			comboArray[t]->insertItem(m_listMenuButtons[i]);
+		// After we initialized the combo boxes, we set the current text (from the buttonObject
+		if (!m_pClonedButton->next(intArray[t]).isEmpty())
+			comboArray[t]->setCurrentText(m_pClonedButton->next(intArray[t]));
 	}
-	// After we initialized the combo boxes, we set the current text (from the buttonObject
-	m_pComboUp   ->setCurrentText(m_pClonedButton->next(NEXT_BUTTON_UP));
-	m_pComboDown ->setCurrentText(m_pClonedButton->next(NEXT_BUTTON_DOWN));
-	m_pComboLeft ->setCurrentText(m_pClonedButton->next(NEXT_BUTTON_LEFT));
-	m_pComboRight->setCurrentText(m_pClonedButton->next(NEXT_BUTTON_RIGHT));
 }
 
 void DialogButton::initActions()
 {
-	// Action1 can only be one of these three ...
+	// Action1 can only be one of these four ...
+ 	// Note: an empty string indicates that the user manually changed the action along the way.
 	m_pComboAction1->insertItem(QString ("jump"));
 	m_pComboAction1->insertItem(QString ("call"));
 	m_pComboAction1->insertItem(QString ("resume"));
@@ -199,6 +203,12 @@ void DialogButton::initActionState ()
 
 	listActions = QStringList::split (STRING_SEPARATOR, qsButtonAction);
 	qsAction1 = listActions[0];
+	if (listActions.count() == 1)	{
+		if (m_pComboAction1->count() <= 3)
+			m_pComboAction1->insertItem (QString ());
+		m_pComboAction1->setCurrentItem (3);
+		return;
+	}
 	qsAction2 = listActions[1];
 	qsAction3 = listActions[2];
 	if (listActions.count() > 3)
@@ -320,6 +330,31 @@ SourceFileInfo *DialogButton::getSelectedSourceFile()
 	return NULL;
 }
 
+void DialogButton::slotEditActionChanged(const QString &qsText)
+{
+	// Okay we detected that the user manually changed the text and as such we want to keep this change.
+	if (!m_bAutomatic)	{
+		m_pEditAction->setPaletteBackgroundColor (QColor(MANUAL_CHANGE));
+		if (m_pComboAction1->count() <= 3)	{
+			m_pComboAction1->insertItem(QString ());
+			m_pComboSourceEntry->clear ();
+			m_pComboSourceEntry->insertItem (QString ());
+
+			m_pComboChapters->clear ();
+			m_pComboSourceFile->hide();
+			m_pComboChapters2->hide();
+			m_pComboChapters->show();
+		}
+		m_pComboAction1->setCurrentItem (3);
+		m_pComboSourceEntry->setCurrentText(qsText);
+	}
+	else	{
+		m_pEditAction->setPaletteBackgroundColor (QColor(255, 255, 255));
+		if (m_pComboAction1->count() > 3)
+			m_pComboAction1->removeItem(3); // remove the last item (0 based)
+	}
+}
+
 void DialogButton::slotAction1(int)
 {
 	// Okay, here we prepare the available actions ...
@@ -363,11 +398,10 @@ void DialogButton::slotAction1(int)
 		for (t=0;t<m_listSubMenus.count();t++)
 			m_pComboSourceEntry->insertItem(m_listSubMenus[t]);
 	}
-	else	{	// resume ...
-		// keep empty ...
-	}
+//	else	{	// resume ...
+//			m_pComboSourceEntry->insertItem(m_pClonedButton->action());
+//	}
 	slotSourceEntry(0);
-
 }
 
 void DialogButton::slotSourceEntry(int)
@@ -388,6 +422,7 @@ void DialogButton::slotSourceEntry(int)
 			// and we also ought to hide m_pComboChapter
 			bHideStatus = false;
 			if (m_pComboAction1->currentText() == QString ("jump"))	{
+				m_pComboSourceFile->clear ();
 				for (t=0;t<pEntry->listFileInfos.count();t++)	{
 					fileInfo.setFile(pEntry->listFileInfos[t]->qsFileName);
 					m_pComboSourceFile->insertItem(fileInfo.fileName());
@@ -471,8 +506,15 @@ void DialogButton::slotChapters(int)
 	}
 	else
 		qsAction3 = QString (" menu 1");
-	QString qsAction = QString (" ")  + qsAction1 + QString (" ") + qsAction2 + qsAction3 + QString (" ; ");
+	
+	QString qsAction = qsAction2;
+	// Here we check that the changes are not manually made by the user ...
+	if (!qsAction1.isEmpty())	{
+		qsAction = QString (" ")  + qsAction1 + QString (" ") + qsAction2 + qsAction3 + QString (" ; ");
+		m_bAutomatic = true;
+	}
 	m_pEditAction->setText(qsAction);
+	m_bAutomatic = false;
 }
 
 void DialogButton::slotChapters2(int)
@@ -503,22 +545,34 @@ void DialogButton::slotChapters2(int)
 	else
 		qsAction3 = QString (" menu 1");
 	QString qsAction = QString (" ")  + qsAction1 + QString (" ") + qsAction2 + qsAction3 + QString (" ; ");
+	m_bAutomatic = true;
 	m_pEditAction->setText(qsAction);
+	m_bAutomatic = false;
 }
 
 void DialogButton::slotHelpAction()
 {
-
+	QMessageBox::warning(this, tr("Action - tag"), tr("If you make manual changes here they will be kept.\n"
+		"If this is the case then the background color will change to orange.\n"
+		"You can reverse these changes by using the drop down boxes above.\n"
+		"This is an advanced feature and should be used with care.\n\n"
+		"Please note that the syntax in the XML file is different to the one displayed here."), 
+		QMessageBox::Ok, QMessageBox::NoButton);
 }
 
 void DialogButton::slotHelpGoto()
 {
-
+	QMessageBox::warning(this, tr("Goto - attributes"), 
+		tr("Here you can specify the button to goto when the user pushes\n"
+		"the up/down/right/left buttons on the remote control.\n\n"
+		"Note: dvdauthor will choose a logical default value for each of those cases."), 
+		QMessageBox::Ok, QMessageBox::NoButton);
 }
 
 void DialogButton::slotHelp()
 {
-
+	QMessageBox::warning(this, "ButtonDialog", "Cool you got a button !!!\n", 
+		QMessageBox::Ok, QMessageBox::NoButton);
 }
 
 void DialogButton::slotAdvanced()
@@ -567,20 +621,24 @@ void DialogButton::slotOkay()
 	QString qsRight  = m_pComboRight->currentText();
 	QString qsLeft   = m_pComboLeft->currentText();
 
-	// Next let us take care of the action. Remember we showed the user something like :
-	// jump my_movie1.mpg chapter 3
-	// this needs to convert to something like ...
-	// jump titleset 2 chapter 3
-	SourceFileEntry *pEntry = getSelectedSourceEntry ();
-	if ( (pEntry) && (pEntry->listFileInfos.count() > 1) )
-		qsAction = m_pComboAction1->currentText() + QString (STRING_SEPARATOR) +
-			m_pComboSourceEntry->currentText() + QString (STRING_SEPARATOR) +
-			m_pComboSourceFile->currentText() + QString (STRING_SEPARATOR) +
-			m_pComboChapters2->currentText();
-	else
-		qsAction = m_pComboAction1->currentText() + QString (STRING_SEPARATOR) +
-			m_pComboSourceEntry->currentText() + QString (STRING_SEPARATOR) +
-			m_pComboChapters->currentText();
+	// if the user has manually changed the action, then we do not want to modify it at all.
+	// Power to the user ...
+	if (m_pEditAction->paletteBackgroundColor() != QColor(MANUAL_CHANGE) )	{
+		// Next let us take care of the action. Remember we showed the user something like :
+		// jump my_movie1.mpg chapter 3
+		// this needs to convert to something like ...
+		// jump titleset 2 chapter 3
+		SourceFileEntry *pEntry = getSelectedSourceEntry ();
+		if ( (pEntry) && (pEntry->listFileInfos.count() > 1) )
+			qsAction = m_pComboAction1->currentText() + QString (STRING_SEPARATOR) +
+				m_pComboSourceEntry->currentText() + QString (STRING_SEPARATOR) +
+				m_pComboSourceFile->currentText() + QString (STRING_SEPARATOR) +
+				m_pComboChapters2->currentText();
+		else
+			qsAction = m_pComboAction1->currentText() + QString (STRING_SEPARATOR) +
+				m_pComboSourceEntry->currentText() + QString (STRING_SEPARATOR) +
+				m_pComboChapters->currentText();
+	}
 
 	m_pClonedButton->setAction (qsAction);
 	m_pClonedButton->setName (qsName);
@@ -588,7 +646,6 @@ void DialogButton::slotOkay()
 	m_pClonedButton->setNext (NEXT_BUTTON_DOWN,  qsDown);
 	m_pClonedButton->setNext (NEXT_BUTTON_LEFT,  qsLeft);
 	m_pClonedButton->setNext (NEXT_BUTTON_RIGHT, qsRight);
-	
 	uint t;
 	// Here we associate the new SourceFileEntry to the Cloned Button ...
 	m_pClonedButton->setSourceFileEntry(NULL);
