@@ -23,7 +23,7 @@ void DialogGeometry::slotWidth()
 	if (m_pCheckAspect->isChecked())	{
 		float fAspect = (float)m_rectGeometry.height() / (float)m_rectGeometry.width();
 		int iWidth = m_pEditWidth->text().toInt();
-		m_pEditHeight->setText (QString ("%1").arg((int)iWidth * fAspect));
+		m_pEditHeight->setText (QString ("%1").arg((int)(fAspect * iWidth)));
 	}
 }
 
@@ -32,6 +32,6 @@ void DialogGeometry::slotHeight()
 	if (m_pCheckAspect->isChecked())	{
 		float fAspect = (float)m_rectGeometry.width() / (float)m_rectGeometry.height();
 		int iHeight = m_pEditHeight->text().toInt();
-		m_pEditWidth->setText (QString ("%1").arg((int)iHeight * fAspect));
+		m_pEditWidth->setText (QString ("%1").arg((int)(fAspect * iHeight)));
 	}
 }
