@@ -23,6 +23,14 @@
 
 #include "global.h"
 #include "dialogtextfont.h"
+#include "dialoganimation.h"
+
+// Here we initialize the static member variables ...
+QFont   DialogTextFont::m_previousFont       = QFont   ();
+QString DialogTextFont::m_previousText       = QString ();
+QPoint  DialogTextFont::m_previousTextAlign  = QPoint  ( Qt::AlignHCenter, Qt::AlignVCenter );
+QColor  DialogTextFont::m_previousBackground = QColor  ( TRANSPARENT_COLOR );
+QColor  DialogTextFont::m_previousForeground = QColor  ( 0, 0, 0 );
 
 DialogTextFont::DialogTextFont(QWidget * parent, const char * name, WFlags f)
 	: uiDialogTextFont (parent, name, f)
@@ -99,8 +107,24 @@ QString DialogTextFont::getText ()
 	return m_pTextEdit->text();
 }
 
+void  DialogTextFont::setAnimation (QString &qsAnimation)
+{
+	m_qsAnimation = qsAnimation;
+}
+
+QString &DialogTextFont::getAnimation ()
+{
+	return m_qsAnimation;
+}
+
 void  DialogTextFont::setTextAlign (QPoint &newAlign)
 {
+	// First we re-set the buttons ...
+	m_pButtonLeft->   setOn(false);
+	m_pButtonRight->  setOn(false);
+	m_pButtonCenter-> setOn(false);
+	m_pButtonJustify->setOn(false);
+
 	if (newAlign.x() == Qt::AlignHCenter)
 		m_pButtonCenter->setOn(true);
 	else if (newAlign.x() == Qt::AlignHCenter)
@@ -145,6 +169,37 @@ bool DialogTextFont::getFit()
 	return m_pButtonFit->isOn();
 }
 
+void DialogTextFont::setRect (QRect &rect)
+{
+	m_pEditX->setText(QString("%1").arg(rect.x()));
+	m_pEditY->setText(QString("%1").arg(rect.y()));
+	m_pEditWidth->setText(QString("%1").arg(rect.width()));
+	m_pEditHeight->setText(QString("%1").arg(rect.height()));
+}
+
+QRect &DialogTextFont::getRect ()
+{
+	static QRect theRect;
+	theRect = QRect (m_pEditX->text().toInt(), m_pEditY->text().toInt(), m_pEditWidth->text().toInt(), m_pEditHeight->text().toInt());
+	return theRect;
+}
+
+void DialogTextFont::setTransparency (float fNewTransparency)
+{
+	if (fNewTransparency > 1.0f)
+		fNewTransparency = 1.0f;
+	if (fNewTransparency < 0.0f)
+		fNewTransparency = 0.0f;
+	m_fTransparency = fNewTransparency;
+	m_pEditTransparency->setText (QString("%1").arg(fNewTransparency));
+	m_pSliderTransparency->setValue ((int)(1000.0*fNewTransparency));
+}
+
+float DialogTextFont::getTransparency ()
+{
+	return m_fTransparency;
+}
+
 void DialogTextFont::updateButtons ()
 {
 	if (m_pButtonLeft->isOn())
@@ -190,14 +245,9 @@ void DialogTextFont::updateButtons ()
 
 void DialogTextFont::initMe()
 {
-	// First we hide the transparency slider and co.
-	// this is for later on ...
-	m_pSlideTransparency->hide();
-	m_pEditTransparency->hide();
-	m_pLabelTransparency->hide();
-
 	// Here we set all available options ...
 	QFontDatabase database;
+	setTransparency (0.0);
 	QStringList listFonts = database.families();
 	m_pListFonts->insertStringList(listFonts);
 	// Next we search for a good starting font ...
@@ -250,13 +300,15 @@ void DialogTextFont::initMe()
 
 	// Here we handle the bad expansion of TextEdit. Keep it in line ...
 	show ();
+
 	QSize size = m_pTextEdit->size();
 	m_pTextEdit->setFixedSize (size);
 	//Finally we set the font of the TextEdit window ...
-	m_pTextEdit->setFont(getFont());
-
-	m_pFrameBackgroundColor->setPaletteForegroundColor (QColor(TRANSPARENT_COLOR));
-	m_backgroundColor = QColor(TRANSPARENT_COLOR);
+	setFont            ( m_previousFont       );
+	setText            ( m_previousText       );
+	setTextAlign       ( m_previousTextAlign  );
+	setBackgroundColor ( m_previousBackground );
+	setForegroundColor ( m_previousForeground );
 	QPainter thePainter (m_pFrameBackgroundColor);
 	thePainter.drawLine(0, 0, m_pFrameBackgroundColor->width(), m_pFrameFontColor->height());
 
@@ -277,8 +329,12 @@ void DialogTextFont::initMe()
 	connect (m_pButtonStrikeout, SIGNAL(toggled (bool)), this, SLOT(slotStrikeout(bool)));
 	connect (m_pButtonUnderline, SIGNAL(toggled (bool)), this, SLOT(slotUnderline(bool)));
 
+	connect (m_pButtonAnimation,  SIGNAL(clicked()), this, SLOT(slotAnimation()));
 	connect (m_pButtonFontColor,  SIGNAL(clicked()), this, SLOT(slotForegroundColor()));
 	connect (m_pButtonBackgroundColor, SIGNAL(clicked()), this, SLOT(slotBackgroundColor()));
+	connect (m_pSliderTransparency, SIGNAL(valueChanged (int)), this, SLOT(slotTransparency(int)));
+
+	connect (buttonOk, SIGNAL(clicked()), this, SLOT(slotOkay()));
 	updateButtons();
 }
 
@@ -309,6 +365,18 @@ void DialogTextFont::slotBackgroundColor ()
 	setBackgroundColor (newColor);
 }
 
+void DialogTextFont::slotTransparency (int iNewValue)
+{
+	// Called from the slider
+	if (iNewValue < 5)
+		iNewValue = 0;
+	if (iNewValue > 995)
+		iNewValue = 1000;
+	// [0.0 .. 1.0]=[0..999]=> 1.0=fully transparent.
+	m_fTransparency = (float)((float)iNewValue/1000.0);
+	m_pEditTransparency->setText (QString("%1").arg(m_fTransparency, 0, 'f', 2));
+}
+
 void DialogTextFont::slotFontFamilyChanged(int)
 {
 	updateFont(0);
@@ -374,8 +442,12 @@ void DialogTextFont::slotVCenter (bool)
 	updateFont(2);
 }
 
-void DialogTextFont::slotFit (bool)
+void DialogTextFont::slotFit (bool bFitForIt)
 {
+	// here we enable - disable the coordinates if the user wants to
+	// fit the box to the text extension.
+	m_pEditWidth-> setEnabled(!bFitForIt);
+	m_pEditHeight->setEnabled(!bFitForIt);
 	updateFont(2);
 }
 
@@ -389,6 +461,26 @@ void DialogTextFont::slotStrikeout (bool)
 	updateFont(2);
 }
 
+void DialogTextFont::slotAnimation ()
+{
+	// This function gets the Animation Dialog
+	// Within this dialo, you can create a script
+	// (or hardcode) Attributes of the object.
+	// Before rendering the menu the script will 
+	// get executed and all data sent to stdout 
+	// will be captured in the data file, wich 
+	// will provide the data for the animation.
+	QString qsEmpty;
+	DialogAnimation dialog ( this );
+	dialog.initMe ( m_qsAnimation, 300, 25.0, DialogAnimation::TypeText );
+	dialog.setFontName ( m_qfFont.toString () );
+	if ( dialog.exec () == QDialog::Accepted )
+		m_qsAnimation = dialog.string ();
+
+	if (m_qsAnimation.length () < 5)
+		m_qsAnimation = qsEmpty;
+}
+
 void  DialogTextFont::updateFont(uint iSwitch)
 {
 	uint t;
@@ -487,6 +579,18 @@ void DialogTextFont::setForegroundColor (QColor &newColor)
 	m_foregroundColor = newColor;
 }
 
+void DialogTextFont::slotOkay()
+{
+	// here we store the last settings in the static members so the next time we open this
+	// dialog we will have the right settings ...
+	m_previousFont = getFont ();
+	m_previousText = getText ();
+	m_previousTextAlign  = getTextAlign ();
+	m_previousForeground = getForegroundColor ();
+	m_previousBackground = getBackgroundColor ();
+
+	accept ();
+}
 
 
 /* scripts ...
