@@ -62,21 +62,18 @@ Execute::~Execute ()
 
 }
 
-void Execute::setPaths(QString qsProjectPath, QString qsTempPath)
-{
-	if (!qsProjectPath.isEmpty())
-		m_qsProjectPath = qsProjectPath;
-	if (!qsTempPath.isEmpty())
-		m_qsTempPath = qsTempPath;
-}
-
 void Execute::initMe ()
 {
 	m_iMaxWait = 10;
 	m_iSeconds = 15;
 	m_iCurrentCommand = 0;
 	m_pDialog = NULL;
-	m_qsTempPath=QString ("/tmp");
+}
+
+void Execute::raise ()
+{
+	if (m_pDialog)
+		m_pDialog->raise ();
 }
 
 void Execute::createDialog(bool bKeep)
@@ -90,7 +87,6 @@ void Execute::createDialog(bool bKeep)
 		delete m_pDialog;
 
 	m_pDialog = new MyDialog ();
-	m_pDialog->setProjectPath(m_qsProjectPath);
 	m_pDialog->show();
 	m_pDialog->editCommandText->clear ();
 	m_pDialog->setCloseDelay(m_iSeconds);
@@ -134,6 +130,19 @@ int Execute::system( QString &commandString, QStringList *pListEnv)
 	return startCommand ();
 }
 
+int Execute::renderMenu (QString qsMenuName)
+{
+	// Here we start rendering the menu ...
+	// This will go to QDVDAuthor::slotRenderMenu and from there to the propper DVDMenu
+	emit (signalRenderMenu(qsMenuName));
+	// Increase the command counter ...
+	m_iCurrentCommand ++;
+	// Start the next process, or start the timer to terminate the whole thing ...
+//	if (startCommand() == 0)
+//		m_pDialog->processingFinished (m_iSeconds);
+	return 1;
+}
+
 int Execute::startCommand ()
 {
 	QStringList *pListEnv = NULL;
@@ -152,21 +161,26 @@ int Execute::startCommand ()
 	// Here we add the command to the top (command line) in the GUI.
 	m_pDialog->editCommandText->append (QString ("cmd> ") + m_commandList[m_iCurrentCommand]);
 
+	// if the command is to render a menu it is done internally and not through a command line (yet)
+	// Thus we do the rendering and return here ...
+	if (m_commandList[m_iCurrentCommand].find( QString(RENDER_MENU)) > -1)
+ 		return renderMenu(m_commandList[m_iCurrentCommand].right(m_commandList[m_iCurrentCommand].length() - QString (RENDER_MENU).length()));
+	
 	// Here we generate a simple shell script to execute the commands under the shell.
 	// QProcess is currently not flexible enough to handle this internal.
-	QFile file(m_qsTempPath + QString("/execute.sh"));
+	QFile file(Global::qsTempPath + QString("/execute.sh"));
 	if ( file.open( IO_WriteOnly ) ) {
 		QTextStream stream( &file );
 		stream << BASH_STRING << m_commandList[m_iCurrentCommand];
 		file.close();
 	}
 	// And here we grant read/write/execute permission.
-	chmod ((const char *)QString(m_qsTempPath + QString("/execute.sh")), S_IEXEC | S_IRUSR | S_IWRITE);
+	chmod ((const char *)QString(Global::qsTempPath + QString("/execute.sh")), S_IEXEC | S_IRUSR | S_IWRITE);
 	// Increase the command counter ...
 	m_iCurrentCommand ++;
 	// Set the script to execute ...
 	clearArguments ();
-	addArgument (QString (m_qsTempPath + QString("/execute.sh")));
+	addArgument (QString (Global::qsTempPath + QString("/execute.sh")));
 	// And eh voila, ici on executer les commands.
 	start (pListEnv);
 	// return to the calling process (thread)
@@ -313,8 +327,6 @@ MyDialog::MyDialog( QWidget* parent, const char* name, bool modal, WFlags fl )
 
 	textOutput = new QTextEdit( splitter1, "textOutput" );
 	textOutput->setPaletteForegroundColor( QColor( 27, 212, 7 ) );
-//	textOutput->setMinimumSize( QSize( 0, 250 ) );
-//	textOutput->setMaximumSize( QSize( 32767, 32767 ) );
 	textOutput->setPaletteBackgroundColor( QColor( 0, 0, 0 ) );
 	textOutput->setWordWrap( QTextEdit::WidgetWidth );
 
@@ -324,11 +336,11 @@ MyDialog::MyDialog( QWidget* parent, const char* name, bool modal, WFlags fl )
 	clearWState( WState_Polished );
 
 	// signals and slots connections
-	connect( buttonExport, SIGNAL( clicked() ), this, SLOT( slotExport() ) );
-	connect( buttonPlay, SIGNAL( clicked() ), this, SLOT( slotPlay() ) );
-	connect( buttonOk, SIGNAL( clicked() ), this, SLOT( accept() ) );
-	connect( buttonCancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
-	connect( checkKeepOpen, SIGNAL( toggled(bool) ), this, SLOT( slotKeepOpen(bool) ) );
+	connect( buttonExport, SIGNAL( clicked() ),     this, SLOT( slotExport() ) );
+	connect( buttonPlay,   SIGNAL( clicked() ),     this, SLOT( slotPlay() ) );
+	connect( buttonOk,     SIGNAL( clicked() ),     this, SLOT( accept() ) );
+	connect( buttonCancel, SIGNAL( clicked() ),     this, SLOT( reject() ) );
+	connect( checkKeepOpen,SIGNAL( toggled(bool) ), this, SLOT( slotKeepOpen(bool) ) );
 
 	m_bDoneProcessing = false;
 	m_pTimer = NULL;
@@ -358,10 +370,6 @@ uint MyDialog::getCloseDelay ()
 {
 	return m_iSeconds;
 }
-void MyDialog::setProjectPath(QString qsProjectPath)
-{
-	m_qsProjectPath = qsProjectPath;
-}
 
 void MyDialog::languageChange()
 {
@@ -383,7 +391,7 @@ void MyDialog::languageChange()
 void MyDialog::slotTimerDone ()
 {
 	static uint iCounter = 0;
-//	static bool bShowRunning = true;
+
 	iCounter ++;
 	if (iCounter > m_iSeconds)	{
 		m_pTimer->stop();
@@ -391,11 +399,6 @@ void MyDialog::slotTimerDone ()
 		editCloseText->setText (tr ("Status : Done."));
 		accept ();
 	}
-//	if (bShowRunning)
-//		editCloseText->setText (QString ("Status : Running."));
-//	else
-//		editCloseText->setText (QString ("Status : "));
-//	bShowRunning = bShowRunning ? false : true;
 	editCloseText->setText (tr ("Status : Close dialog in %1 seconds.").arg (m_iSeconds - iCounter + 1));
 }
 
@@ -403,26 +406,27 @@ void MyDialog::processingFinished (int iSeconds)
 {
 	// We're done, timer stuff now ok
 	m_bDoneProcessing = true;
-
+	QString qsStorage = Global::qsTempPath + QString ("/") + Global::qsProjectName + QString ("/output.txt");
+	saveOutput (qsStorage);
 	// Start the timer if the checkbox is clear
 	if (!checkKeepOpen->isChecked())        {
 		startTimer(iSeconds);
 	}
 	// First we check if qplayer is there and executable ...
-	QFileInfo fileInfo ("qplayer");
+	QFileInfo fileInfo (Global::qsExternalPlayer);
 	if (!fileInfo.exists())
 		return;
 	// next we check if it is executable ...
 	if (!fileInfo.isExecutable())
 		return;
 	// last we check if there has been something clreated to play at all ...
-	fileInfo.setFile(m_qsProjectPath + QString ("/VIDEO_TS/VIDEO_TS.BUP"));
+	fileInfo.setFile(Global::qsProjectPath + QString ("/VIDEO_TS/VIDEO_TS.BUP"));
 	if (!fileInfo.exists())
 		return;
-	fileInfo.setFile(m_qsProjectPath + QString ("/VIDEO_TS/VIDEO_TS.IFO"));
+	fileInfo.setFile(Global::qsProjectPath + QString ("/VIDEO_TS/VIDEO_TS.IFO"));
 	if (!fileInfo.exists())
 		return;
-	fileInfo.setFile(m_qsProjectPath + QString ("/VIDEO_TS/VIDEO_TS.VOB"));
+	fileInfo.setFile(Global::qsProjectPath + QString ("/VIDEO_TS/VIDEO_TS.VOB"));
 	if (!fileInfo.exists())
 		return;
 	buttonPlay->setEnabled(true);
@@ -465,18 +469,21 @@ void MyDialog::slotKeepOpen (bool bKeepOpen)
 
 void MyDialog::slotPlay ()
 {
-printf ("execute.cpp ::: slotPlay <%s>\n", (const char *)m_qsProjectPath);
-	system (QString ("qplayer dvd:/%1/VIDEO_TS/").arg(m_qsProjectPath));	//dvd:/home/varol/dvdproject/dvd/VIDEO_TS/");
+	system (QString ("%1 dvd:/%2/VIDEO_TS/ &").arg(Global::qsExternalPlayer).arg(Global::qsProjectPath));
 }
 
 void MyDialog::slotExport ()
 {
-	QString qsSaveFileName = QFileDialog::getSaveFileName( m_qsProjectPath, tr("Text files (*.txt *.TXT)"),
+	QString qsSaveFileName = QFileDialog::getSaveFileName( Global::qsProjectPath, tr("Text files (*.txt *.TXT)"),
 		this, tr("Save file dialog. Choose a filename to save under"));
   	if (qsSaveFileName.isEmpty())
 		return;
+	saveOutput (qsSaveFileName);
+}
 
-	QFile file( qsSaveFileName );
+void MyDialog::saveOutput (QString qsFileName)
+{
+	QFile file( qsFileName );
 	if ( file.open( IO_WriteOnly ) ) {
 		QTextStream stream( &file );
 		stream << editCommandText->text() << "\n";
