@@ -108,10 +108,18 @@ void FrameObject::drawContents (QPainter *painter)
 	theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
 	theMatrix.rotate (modifiers()->fRotate);
 	theMatrix.shear  (modifiers()->fShearX, modifiers()->fShearY);
-	// Here we get the rect that encompasses the button for this object.
-	m_boundingRect = theMatrix.mapRect(theRect);
+	
+	// Here we draw the rect that encompasses thebutton (think of rotated)
+	QRect r (theMatrix.mapRect(theRect));
 	if (m_bDrawRect)
-		painter->drawRect(m_boundingRect);
+		painter->drawRect(r);
+	// Now we calculate the boundingRect by adding the FrameWidth to it.
+	r = QRect (theRect.x()-(int)(width()/2.0), theRect.y()-(int)(width()/2.0), theRect.width()+width(), theRect.height()+width());
+	m_boundingRect = theMatrix.mapRect(r);
+
+// Here we add the frameWidth to the boundingRect
+//	m_boundingRect = QRect (r.x()-(int)(width()/2.0), r.y()-(int)(width()/2.0), r.width()+width(), r.height()+width());
+
 	painter->setWorldMatrix(theMatrix);
 
 	painter->drawRect(theRect);
@@ -119,6 +127,15 @@ void FrameObject::drawContents (QPainter *painter)
 	painter->setWorldMatrix(theMatrix);
 }
 
+void FrameObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int)
+{
+	// Next is to set the AnimationAttributes
+	for (uint t=0;t<m_listAnimationAttributes.count();t++)
+		m_listAnimationAttributes[t]->setValue (iRenderFrameNumber);
+
+	drawContents (pPainter);
+}
+
 bool FrameObject::mouseMoveEvent (QMouseEvent *pEvent)
 {
 	// This will move the textObject around and around and around we go ...
@@ -142,22 +159,36 @@ bool FrameObject::mousePressEvent (QMouseEvent *pEvent)
 {
 	m_currentMousePos = pEvent->pos();
 	if (pEvent->button() == Qt::RightButton)	{
-		QPopupMenu *pMenu = new QPopupMenu(m_pParent);
-		pMenu->insertItem ( tr ("Edit ...")  , this, SLOT(slotEdit()));
-		pMenu->insertItem ( tr ("Matrix ..."), this, SLOT(slotMatrix()));
-		pMenu->insertItem ( tr ("Delete")    , this, SLOT(slotDelete()));
-		pMenu->insertSeparator();
-		pMenu->insertItem ( tr ("Add Text")   , this, SLOT(slotAddText()));
-		pMenu->insertItem ( tr ("Add Image")  , this, SLOT(slotAddImage()));
-		pMenu->insertItem ( tr ("Add Movie")  , this, SLOT(slotAddMovie()));
-		pMenu->insertSeparator();
-		pMenu->insertItem ( tr ("Define as Button") , this, SLOT(slotDefineAsButton()));
-		int iReturn = pMenu->exec(pEvent->globalPos());
+		QPoint globalPos = pEvent->globalPos();
+
+		QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
+		pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
+		pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
+		globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
+		pStackMenu->popup(globalPos, 1);
+
+		if (m_pContextMenu)
+			delete m_pContextMenu;
+		m_pContextMenu = new QPopupMenu(m_pParent);
+		m_pContextMenu->insertItem ( tr ("Edit ...")  , this, SLOT(slotEdit()));
+		m_pContextMenu->insertItem ( tr ("Matrix ..."), this, SLOT(slotMatrix()));
+		m_pContextMenu->insertItem ( tr ("Delete")    , this, SLOT(slotDelete()));
+		m_pContextMenu->insertSeparator();
+		m_pContextMenu->insertItem ( tr ("Add Text")   , this, SLOT(slotAddText()));
+		m_pContextMenu->insertItem ( tr ("Add Image")  , this, SLOT(slotAddImage()));
+		m_pContextMenu->insertItem ( tr ("Add Movie")  , this, SLOT(slotAddMovie()));
+		m_pContextMenu->insertSeparator();
+		m_pContextMenu->insertItem ( tr ("Define as Button") , this, SLOT(slotDefineAsButton()));
+		m_pContextMenu->exec(pEvent->globalPos(), 4);
+
+		delete pStackMenu;
+		if (m_pContextMenu)
+			delete m_pContextMenu;
+		m_pContextMenu = NULL;
 		// Here we mark that the user called a menu item thus we don't want the
 		// base classes to continue with the mouse event
-		if (iReturn != -1)
+//		if (iReturn != -1)
 			return true;
-//printf ("Clicked inside TextButton\n");
 	}
 	else
 		m_bDrawRect = true;
@@ -174,6 +205,7 @@ bool FrameObject::mouseReleaseEvent (QMouseEvent *)
 
 bool FrameObject::mouseDoubleClickEvent (QMouseEvent *)
 {
+	QString qsAnimation;
 	DialogFrame frameDialog (m_pParent);
 	frameDialog.initMe(this);
 	if (frameDialog.exec() == QDialog::Rejected)
@@ -181,6 +213,8 @@ bool FrameObject::mouseDoubleClickEvent (QMouseEvent *)
 	setFrameWidth(frameDialog.frameWidth ());
 	setFrameStyle(frameDialog.style());
 	setFrameJoin (frameDialog.join ());
+	qsAnimation = frameDialog.animation ();
+	setAnimation ( qsAnimation );
 	if (color() != frameDialog.color())	{
 		// This emit signal is only caught when in ButtonDialog and the Selected, or Highlighted mask 
 		// was changed (I.e. This Object is in one of those two frames).
@@ -261,11 +295,17 @@ void FrameObject::createStructure (QListViewItem *pParentItem)
 	QListViewItem *pFrameItem;
 	QListViewItem *pModifierItem;
 
-	QString qsName (tr("Frame Object"));
-	QString qsInfo = QString ("%1 - (%2, %3, %4)").arg(width()).
-			arg(m_colorFrame.red()).
+	QString qsName (tr("Frame (%2, %3, %4)").
+			arg(m_colorFrame.red  ()).
 			arg(m_colorFrame.green()).
-			arg(m_colorFrame.blue());
+			arg(m_colorFrame.blue ()));
+	setName (qsName);
+
+	qsName  = tr("Frame Object");
+	QString qsInfo = QString ("%1 - (%2, %3, %4)").arg(width()).
+			arg(m_colorFrame.red  ()).
+			arg(m_colorFrame.green()).
+			arg(m_colorFrame.blue ());
 
 	pFrameItem = new QListViewItem(pParentItem, qsName, qsInfo);
 	pFrameItem->setExpandable (TRUE);
@@ -310,11 +350,6 @@ void FrameObject::slotMatrix()
 	pDialog->show();
 }
 
-void FrameObject::slotDelete()
-{
-	emit (signalDeleteMe(this));
-}
-
 void FrameObject::slotAddText()
 {
 	QMessageBox::warning (NULL, tr ("Not Implemented yet."), tr("Not Implemented yet."),
@@ -354,5 +389,27 @@ MenuObject *FrameObject::clone()
 	return pNewObject;
 }
 
-
+AnimationAttribute *FrameObject::getSpecificAttributes (long iMaxNumberOfFrames, QString qsProperty)
+{
+	AnimationAttribute *pAnimAttr = NULL;
+	if (qsProperty == "color.red")	{
+		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorFrame, TYPE_COLOR_RED);
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorFrame.red(), callMeBack);
+	}
+	else if (qsProperty == "color.green")	{
+		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorFrame, TYPE_COLOR_GREEN);
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorFrame.green(), callMeBack);
+	}
+	else if (qsProperty == "color.blue")	{
+		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorFrame, TYPE_COLOR_BLUE);
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorFrame.blue(), callMeBack);
+	}
+	else if (qsProperty == "frameWidth")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_iFrameWidth, &m_iFrameWidth);
+	else if (qsProperty == "frameStyle")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_iFrameStyle, &m_iFrameStyle);
+	else if (qsProperty == "frameJoin")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_iFrameJoin, &m_iFrameJoin);
+	return pAnimAttr;
+}
 
