@@ -22,7 +22,8 @@ public:
 	// Public functions needed for the abstract base class.
 	FrameObject (QWidget *pParent = 0);
 	virtual ~FrameObject();
-	virtual void drawContents(QPainter *);
+	virtual void drawContents          (QPainter *);
+	virtual void drawContents          (QPainter *, int, int);
 	virtual bool mouseMoveEvent        (QMouseEvent *);
 	virtual bool mousePressEvent       (QMouseEvent *);
 	virtual bool mouseReleaseEvent     (QMouseEvent *);
@@ -33,12 +34,6 @@ public:
 	virtual void createStructure (QListViewItem *);
 	virtual MenuObject *clone();
 	virtual void replaceColor (QColor, QColor);
-	
-signals:
-	void signalDefineAsButton(MenuObject *);
-	void signalDeleteMe(MenuObject *);
-//	void signalModifyMe(MenuObject *);
-	void signalUpdateStructure();
 
 public:
 	// Further public functions not dervied from the base class.
@@ -55,12 +50,14 @@ public:
 protected slots:
 	virtual void slotEdit();
 	virtual void slotMatrix();
-	virtual void slotDelete();
 	virtual void slotAddText();
 	virtual void slotAddImage();
 	virtual void slotAddMovie();
 	virtual void slotDefineAsButton();
 
+protected:
+	virtual AnimationAttribute *getSpecificAttributes (long, QString);
+
 private:
 	QColor  m_colorFrame;
 	int     m_iFrameWidth;
