@@ -10,6 +10,7 @@
 **
 ****************************************************************************/
 #include <qmessagebox.h>
+#include <qpushbutton.h>
 #include <qpopupmenu.h>
 #include <qfileinfo.h>
 #include <qlistview.h>
@@ -26,6 +27,7 @@
 #include "imageobject.h"
 #include "dialogmatrix.h"
 #include "dialoggeometry.h"
+#include "dialoganimation.h"
 
 ImageObject::ImageObject (QWidget *pParent)
 	: MenuObject (pParent)
@@ -46,6 +48,12 @@ void ImageObject::setPixmap(QPixmap &thePixmap)
 
 void ImageObject::setFile (QString fileName)
 {
+	QString qsExtractionPath;
+	QFileInfo fileInfo(fileName);
+	m_qsFileName = fileInfo.fileName();
+	setName(m_qsFileName);
+	qsExtractionPath = fileInfo.baseName ();
+	setExtractionPath(qsExtractionPath);
 	m_qsFileName = fileName;
 //	m_pixmap = QPixmap (fileName);
 }
@@ -112,6 +120,7 @@ void ImageObject::drawContents (QPainter *painter)
 
 	//. then we apply the other modifications ...
 //	theMatrix.scale  (manipulator().fZoom, manipulator().fZoom);
+	theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
 	theMatrix.rotate (manipulator().fRotate);
 	theMatrix.shear  (manipulator().fShearX, manipulator().fShearY);
 
@@ -125,11 +134,11 @@ void ImageObject::drawContents (QPainter *painter)
 	// Here we re-set the world matrix and translate the newly drawn ... thing ...
 	if (m_bDrawRect)
 		painter->drawRect(theRect);
-
+	
 	theMatrix.reset();
 	painter->setWorldMatrix(theMatrix);
 	
-	// check if we hve a complete transparency, in which case we don't even need to bother...
+	// check if we have a complete transparency, in which case we don't even need to bother...
 	if (manipulator().fTransparency == 1.0)
 		return;
 
@@ -162,7 +171,7 @@ void ImageObject::drawContents (QPainter *painter)
 			if (fTargetTrans != 0.0)	{
 				QPixmap sourcePix (iSourceWidth, iSourceHeight);
 				bitBlt (&sourcePix, 0, 0, painter->device(), iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight, Qt::CopyROP, true);
-				// To get Pixe information we need a QImage however ...
+				// To get Pixel information we need a QImage however ...
 				sourceImg = sourcePix.convertToImage();
 				// Now we can get the original Pixel information ...
 //				Note: This ought to be done in the updatePixmap () - function
@@ -199,6 +208,17 @@ void ImageObject::drawContents (QPainter *painter)
 		}
 	}
 }
+
+void ImageObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int)
+{
+	// Next is to set the AnimationAttributes
+	for (uint t=0;t<m_listAnimationAttributes.count();t++)
+		m_listAnimationAttributes[t]->setValue (iRenderFrameNumber);
+//printf ("<%ld>X1=<%d> Y1=<%d> trans=<%03f>\n", iRenderFrameNumber, m_rect.x(), m_rect.y(), m_imageManipulator.fTransparency);
+
+	drawContents (pPainter);
+}
+
 /* Without transparency ...
 void ImageObject::drawContents (QPainter *painter)
 {
@@ -290,20 +310,21 @@ void ImageObject::updatePixmap()
 	// Here we calculate the center point of gravity (rotation)
 	QPoint centerPos;
 
-
-	// deep copy of the image.
 	if (fileName().isEmpty())
 		return;
 
 	QImage theImage(fileName());
 	if (theImage.isNull())
 		return;
+	theImage = theImage.smoothScale ( rect ().width(), rect().height(), QImage::ScaleFree);
+
 	centerPos.setX (rect().x() + (int)((float)rect().width () / 2.0));
 	centerPos.setY (rect().y() + (int)((float)rect().height() / 2.0));
 	// First we translate to the appropriate location,
 	theMatrix.translate ((double)centerPos.x(), (double)centerPos.y());
 	// then we apply the other modifications ...
-	theMatrix.scale  (manipulator().fZoom, manipulator().fZoom);
+	theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
+//	theMatrix.scale  (manipulator().fZoom, manipulator().fZoom);
 	// Here we create the scaled image ...
 	theImage = theImage.xForm ( theMatrix );
 
@@ -475,8 +496,10 @@ void ImageObject::createStructure (QListViewItem *pParentItem)
 	QListViewItem *pButtonItem;
 	QListViewItem *pModifierItem;
 	QFileInfo fileInfo(m_qsFileName);
+	QString qsName;
 	
-	QString qsName ("Image Object");
+	qsName = QString ("Image Object");
+
 	pButtonItem = new QListViewItem(pParentItem, qsName, fileInfo.fileName());
 	pButtonItem->setExpandable (TRUE);
 
@@ -547,24 +570,38 @@ bool ImageObject::mousePressEvent (QMouseEvent *pEvent)
 {
 	m_currentMousePos = pEvent->pos();
 	if (pEvent->button() == Qt::RightButton)	{
-		QPopupMenu *pMenu = new QPopupMenu(m_pParent);
-		pMenu->insertItem ( QString ("Edit ...")    , this, SLOT(slotEdit()));
-		pMenu->insertItem ( QString ("Geometry ..."), this, SLOT(slotGeometry()));
-		pMenu->insertItem ( QString ("Matrix ...")  , this, SLOT(slotMatrix()));
-		pMenu->insertItem ( QString ("Delete")      , this, SLOT(slotDelete()));
-		pMenu->insertSeparator();
-		pMenu->insertItem ( QString ("Rotate 90")   , this, SLOT(slotRotate90 ()));
-		pMenu->insertItem ( QString ("Rotate 180")  , this, SLOT(slotRotate180()));
-		pMenu->insertItem ( QString ("Rotate 270")  , this, SLOT(slotRotate270()));
-		pMenu->insertSeparator();
-		pMenu->insertItem ( QString ("Add Frame")   , this, SLOT(slotAddFrame()));
-		pMenu->insertItem ( QString ("Add Text")    , this, SLOT(slotAddText()));
-		pMenu->insertSeparator();
-		pMenu->insertItem ( QString ("Define as Button") , this, SLOT(slotDefineAsButton()));
-		int iReturn = pMenu->exec(pEvent->globalPos());
+		QPoint globalPos = pEvent->globalPos();
+		QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
+		pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
+		pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
+		globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
+		pStackMenu->popup(globalPos, 1);
+
+		if (m_pContextMenu)
+			delete m_pContextMenu;
+		m_pContextMenu = new QPopupMenu(m_pParent);
+		m_pContextMenu->insertItem ( QString ("Edit ...")      , this, SLOT(slotEdit()));
+		m_pContextMenu->insertItem ( QString ("Properties ..."), this, SLOT(slotProperties()));
+		m_pContextMenu->insertItem ( QString ("Matrix ...")    , this, SLOT(slotMatrix()));
+		m_pContextMenu->insertItem ( QString ("Delete")        , this, SLOT(slotDelete()));
+		m_pContextMenu->insertSeparator();
+		m_pContextMenu->insertItem ( QString ("Rotate 90")     , this, SLOT(slotRotate90 ()));
+		m_pContextMenu->insertItem ( QString ("Rotate 180")    , this, SLOT(slotRotate180()));
+		m_pContextMenu->insertItem ( QString ("Rotate 270")    , this, SLOT(slotRotate270()));
+		m_pContextMenu->insertSeparator();
+		m_pContextMenu->insertItem ( QString ("Add Frame")     , this, SLOT(slotAddFrame()));
+		m_pContextMenu->insertItem ( QString ("Add Text")      , this, SLOT(slotAddText()));
+		m_pContextMenu->insertSeparator();
+		m_pContextMenu->insertItem ( QString ("Define as Button") , this, SLOT(slotDefineAsButton()));
+		// Blocking call.
+		m_pContextMenu->exec(pEvent->globalPos(), 6);
+		delete pStackMenu;
+		if (m_pContextMenu)
+			delete m_pContextMenu;
+		m_pContextMenu = NULL;
 		// Here we mark that the user called a menu item thus we don't want the
 		// base classes to continue with the mouse event
-		if (iReturn != -1)
+//		if (iReturn != -1)
 			return true;
 	}
 	else
@@ -592,10 +629,13 @@ void ImageObject::slotEdit()
 	mouseDoubleClickEvent(NULL);
 }
 
-void ImageObject::slotGeometry()
+void ImageObject::slotProperties()
 {
 	DialogGeometry *pGeometry = new DialogGeometry ();
 	pGeometry->initMe(rect());
+	
+	connect ( pGeometry->m_pButtonAnimation, SIGNAL(clicked()), this, SLOT(slotAnimation()) );
+	
 	if (pGeometry->exec() == QDialog::Accepted)	{
 		int iX, iY, iWidth, iHeight;
 		iX      = pGeometry->m_pEditX->text().toInt();
@@ -604,8 +644,29 @@ void ImageObject::slotGeometry()
 		iHeight = pGeometry->m_pEditHeight->text().toInt();
 		QRect rect (iX, iY, iWidth, iHeight);
 		setRect (rect);
+		updatePixmap ();
 		emit (signalUpdatePixmap());
 	}
+	delete pGeometry;
+}
+
+void ImageObject::slotAnimation ()
+{
+	// This function gets the Animation Dialog
+	// Within this dialo, you can create a script
+	// (or hardcode) Attributes of the object.
+	// Before rendering the menu the script will 
+	// get executed and all data sent to stdout 
+	// will be captured in the data file, wich 
+	// will provide the data for the animation.
+	QString qsEmpty;
+	DialogAnimation dialog;
+	dialog.initMe ( animation(), 300, 25.0, DialogAnimation::TypeImage );
+	if ( dialog.exec () == QDialog::Accepted )
+		setAnimation ( dialog.string () );
+
+	if (animation().length () < 5)
+		setAnimation ( qsEmpty );
 }
 
 void ImageObject::slotRotate90()
@@ -637,15 +698,9 @@ void ImageObject::rotate(float fRot)
 	parent()->update();
 }
 
-void ImageObject::slotDelete()
-{
-//printf ("ImageObject::slotDelete -=> Delete it ...\n");
-	emit (signalDeleteMe((MenuObject *)this));
-}
-
 void ImageObject::slotMatrix()
 {
-	QMessageBox::warning (NULL, QString ("Warning"), QString ("This Dialog is very instabel ...\n"), QMessageBox::Ok,  QMessageBox::Ok);
+	QMessageBox::warning (NULL, QString ("Warning"), QString ("This Dialog is very instabel ...\n"), QMessageBox::Ok,  QMessageBox::NoButton);
 
 	DialogMatrix *pDialog = new DialogMatrix(MenuObject::parent());
 	pDialog->initMe(this);
@@ -685,4 +740,47 @@ MenuObject *ImageObject::clone()
 	return pNewObject;
 }
 
+AnimationAttribute *ImageObject::getSpecificAttributes (long iMaxNumberOfFrames, QString qsProperty)
+{
+	AnimationAttribute *pAnimAttr = NULL;
+
+	if (qsProperty == "zoom")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fZoom, &m_imageManipulator.fZoom);
+	else if (qsProperty == "rotate")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fRotate, &m_imageManipulator.fRotate);
+	else if (qsProperty == "shear.x")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fShearX, &m_imageManipulator.fShearX);
+	else if (qsProperty == "shear.y")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fShearY, &m_imageManipulator.fShearY);
+	else if (qsProperty == "scale.x")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fScaleX, &m_imageManipulator.fScaleX);
+	else if (qsProperty == "scale.y")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fScaleY, &m_imageManipulator.fScaleY);
+	else if (qsProperty == "transparency")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fTransparency, &m_imageManipulator.fTransparency);
+	else if (qsProperty == "backgroundFileName")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.backgroundFileName, &m_imageManipulator.backgroundFileName);
+	else if (qsProperty == "showBackground")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.bShowBackground, &m_imageManipulator.bShowBackground);
+	else if (qsProperty == "startPos.x")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.iStartX, &m_imageManipulator.iStartX);
+	else if (qsProperty == "startPos.y")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.iStartY, &m_imageManipulator.iStartY);
+	else if (qsProperty == "res.x")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.iXRes, &m_imageManipulator.iXRes);
+	else if (qsProperty == "res.y")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.iYRes, &m_imageManipulator.iYRes);
+	else if (qsProperty == "aspectRatio")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fAspectRatio, &m_imageManipulator.fAspectRatio);
+	else if (qsProperty == "blendColor.red")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fRed, &m_imageManipulator.fRed);
+	else if (qsProperty == "blendColor.green")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fGreen, &m_imageManipulator.fGreen);
+	else if (qsProperty == "blendColor.blue")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fBlue, &m_imageManipulator.fBlue);
+	else if (qsProperty == "brightness")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_imageManipulator.fBrightness, &m_imageManipulator.fBrightness);
+
+	return pAnimAttr;
+}
 
