@@ -24,6 +24,7 @@ public:
 	ImageObject (QWidget *pParent = 0);
 	virtual ~ImageObject();
 	virtual void drawContents(QPainter *);
+	virtual void drawContents(QPainter *, int, int);
 	virtual bool mouseMoveEvent        (QMouseEvent *);
 	virtual bool mousePressEvent       (QMouseEvent *);
 	virtual bool mouseReleaseEvent     (QMouseEvent *);
@@ -34,41 +35,40 @@ public:
 	virtual void createStructure (QListViewItem *);
 	virtual MenuObject *clone();
 
-signals:
-	void signalDefineAsButton(MenuObject *);
-	void signalDeleteMe(MenuObject *);
-	void signalModifyMe(MenuObject *);
-	void signalUpdateStructure();
-
 public:
 	// Further public functions not dervied from the base class.
+	virtual void setPixmap(QPixmap &);
+	virtual void updatePixmap();
 	void setManipulator(ImageManipulator &);
-	void setPixmap(QPixmap &);
 	void setFile (QString);
 	void setZoom (float);
-	void updatePixmap();
 	QPixmap &pixmap ();
 	QString &fileName();
 	float    zoom ();
 	virtual Modifiers *modifiers();
 	ImageManipulator &manipulator();
 
+signals:
+	void signalModifyMe(MenuObject *);
+
+	
 protected:
+	virtual AnimationAttribute *getSpecificAttributes (long, QString);
 	void rotate (float);
 
 protected slots:
-	virtual void slotEdit     ();
-	virtual void slotGeometry ();
-	virtual void slotRotate90 ();
-	virtual void slotRotate180();
-	virtual void slotRotate270();
-	virtual void slotDelete   ();
-	virtual void slotMatrix   ();
-	virtual void slotAddFrame ();
-	virtual void slotAddText  ();
+	virtual void slotEdit       ();
+	virtual void slotProperties ();
+	virtual void slotRotate90   ();
+	virtual void slotRotate180  ();
+	virtual void slotRotate270  ();
+	virtual void slotMatrix     ();
+	virtual void slotAddFrame   ();
+	virtual void slotAddText    ();
+	virtual void slotAnimation  ();
 	virtual void slotDefineAsButton();
 
-private:
+protected:
 	QString m_qsFileName;
 	QPixmap m_pixmap;
 	ImageManipulator m_imageManipulator;
