@@ -3,11 +3,14 @@
 #include <qtextcodec.h>
 #include <qdir.h>
 
+#include "global.h"
 #include "dvdmenu.h"
 #include "qdvdauthor.h"
 
 int main( int argc, char ** argv )
 {
+	Global::pLogObject = new Log(Log::logDebug);
+	int iReturn = 0; 
 	QApplication application( argc, argv );
 	// translation file for Qt
 	QTranslator qt( 0 );
@@ -15,19 +18,17 @@ int main( int argc, char ** argv )
 	qt.load( QString( "qt_" ) + QTextCodec::locale(), "." );
 	application.installTranslator( &qt );
 
-	// translation file for my application strings
-	QTranslator myapp( 0 );
-	// Under ~/.qdvdauthor/
-	QDir::home().path();
-	myapp.load( QString(QDir::home().path() + "/.qdvdauthor/qdvdauthor_" ) + QTextCodec::locale(), "." );
-	application.installTranslator( &myapp );
-
 	QDVDAuthor dvdAuthor;
 	VMGMenu *pDVDMenu = new VMGMenu (&dvdAuthor);
 
 	dvdAuthor.addDVDMenu(pDVDMenu, true);
 	dvdAuthor.show();
+	dvdAuthor.postInit ();
 	application.connect( &application, SIGNAL( lastWindowClosed() ), &application, SLOT( quit() ) );
-	return application.exec();
+	iReturn = application.exec();
+
+	delete Global::pLogObject;
+	Global::pLogObject = NULL;
+	return iReturn;
 }
 
