@@ -14,6 +14,7 @@
 #include <qpixmap.h>
 #include "menuobject.h"
 
+class MenuPreview;
 
 class ObjectCollection : public MenuObject
 {
@@ -22,7 +23,8 @@ public:
 	// Public functions needed for the abstract base class.
 	ObjectCollection (QWidget *pParent = 0);
 	virtual ~ObjectCollection();
-	virtual void drawContents(QPainter *);
+	virtual void drawContents          (QPainter *);
+	virtual void drawContents          (QPainter *, int, int);
 	virtual bool mouseMoveEvent        (QMouseEvent *);
 	virtual bool mousePressEvent       (QMouseEvent *);
 	virtual bool mouseReleaseEvent     (QMouseEvent *);
@@ -32,6 +34,15 @@ public:
 	virtual bool writeProjectFile (QDomElement &);
 	virtual void createStructure (QListViewItem *);
 
+public:
+	int         getCount ();
+	MenuObject *getObject (int);
+
+	bool readObjects (QDomNode &, MenuPreview *);
+	void deleteAllObjects (bool);
+	void append (MenuObject *, bool b=true);
+	
+
 signals:
 	void signalDefineAsButton(MenuObject *);
 	void signalDeleteMe(MenuObject *);
@@ -45,6 +56,15 @@ protected slots:
 	virtual void slotAddImage();
 	virtual void slotAddMovie();
 	virtual void slotDefineAsButton();
+
+protected:
+	virtual AnimationAttribute *getSpecificAttributes (long, QString);
+
+private:
+	QValueList<MenuObject *> m_listObjectCollection;
+	QValueList<bool>         m_listDeleteThisObject;
+	bool m_bDeleteAllObjects;
 };
 
 #endif	// OBJECTCOLLECTION_H
+
