@@ -4,59 +4,117 @@
 #ifndef QDVDAUTHORINIT_H
 #define QDVDAUTHORINIT_H
 
-#define INIT_FILE_NAME "/.qdvdauthor/qdvdauthor.ini"
+// This is the version number for the Init-file
+#define INIT_VERSION  1.5
 
-#define INIT_DOCTYPE  ""
-#define TAG_INIT      "QDVDAuthorInitFile"
-#define TAG_COLOR     "Color"
-#define TAG_EXECUTE   "ExecuteInterface"
-#define TAG_PAL       "Pal"
-#define TAG_NTSC      "Ntsc"
-#define TAG_DVDAUTHOR "Dvdauthor"
-#define TAG_BURNING   "Burning"
-#define TAG_BLOCK     "Block"
-#define TAG_COMMAND   "Command"
-#define TAG_COMMENT   "Comment"
+#define AUTOSAVE_FILE_NAME "/.qdvdauthor/autosave.xml"
+#define INIT_DIR_NAME  "/.qdvdauthor/"
+#define INIT_FILE_NAME "qdvdauthor.ini"
 
-#define ATTRIB_NUMBER    "number"
-#define ATTRIB_HIDDEN    "hidden"
-#define ATTRIB_NAME      "name"
-#define ATTRIB_COLOR     "color"
-#define ATTRIB_DEFAULT   "default"
-#define ATTRIB_BLOCKNAME "blockname"
+#define INIT_DOCTYPE           ""
+#define TAG_INIT               "QDVDAuthorInitFile"
+#define TAG_PREFERRED_ENGINE   "PreferredEngine"
+#define TAG_EXTERNAL_PLAYER    "ExternalPlayer"
+#define TAG_COLOR              "Color"
+#define TAG_PATH               "Path"
+#define TAG_HISTORY            "History"
+#define TAG_EXECUTE            "ExecuteInterface"
+#define TAG_CONVERT            "Convert"
+#define TAG_PAL                "Pal"
+#define TAG_NTSC               "Ntsc"
+#define TAG_DVDAUTHOR          "Dvdauthor"
+#define TAG_BURNING            "Burning"
+#define TAG_BLOCK              "Block"
+#define TAG_SUBBLOCK           "SubBlock"
+#define TAG_COMMAND            "Command"
+#define TAG_COMMENT            "Comment"
+#define TAG_DRAGNDROP          "DragNDrop"
+#define TAG_FONT               "Font"
 
+#define ATTRIB_DND_THUMBNAIL   "thumbnail_size"
+#define ATTRIB_DND_BUTTON      "button_size"
+#define ATTRIB_DND_BUTTON_TYPE "button_type"
+#define ATTRIB_DND_WITH_TEXT   "with_text"
+#define ATTRIB_DND_TEXT_POS    "text_pos"
+#define ATTRIB_DND_START       "start_offset"
+#define ATTRIB_DND_DURATION    "duration"
+#define ATTRIB_DND_COLOR       "color"
+#define ATTRIB_DND_START_WHEN  "start_when"
+#define ATTRIB_DND_NICE        "nice"
+
+#define ATTRIB_VERSION           "version"
+#define ATTRIB_STYLE             "style"
+#define ATTRIB_AUTOSAVE          "autosave"
+#define ATTRIB_ACTIVE            "active"
+#define ATTRIB_MAX_HISTORY       "max_history"
+#define ATTRIB_MAX_THREADS       "max_threads"
+#define ATTRIB_DELETE_OLDER_THAN "delete_older_than"
+#define ATTRIB_VISIBLE_REGION    "visible_region"
+#define ATTRIB_NUMBER            "number"
+#define ATTRIB_HIDDEN            "hidden"
+#define ATTRIB_EDITABLE          "editable"
+#define ATTRIB_CANMODIFY         "canmodify"
+#define ATTRIB_NAME              "name"
+#define ATTRIB_COLOR             "color"
+#define ATTRIB_DEFAULT           "default"
+#define ATTRIB_BLOCKNAME         "blockname"
+
+#define BLOCK_MOVIE_CONVERT    "MOVIE_CONVERT"
+#define BLOCK_AUDIO_CONVERT    "AUDIO_CONVERT"
 #define BLOCK_MOVIE_BACKGROUND "MOVIE_BACKGROUND"
 #define BLOCK_IMAGE_BACKGROUND "IMAGE_BACKGROUND"
 #define BLOCK_EMPTY_SOUND      "EMPTY_SOUND"
 #define BLOCK_MPLEX            "MPLEX"
 #define BLOCK_SPUMUX           "SPUMUX"
 #define BLOCK_OTHERS           "OTHERS"
+#define SUB_BLOCK_TRANSCODE    "Transcode"
+#define SUB_BLOCK_MENCODER     "MEncoder"
 
 #include "dvdmenu.h"
 #include "dialogexecute.h"	// get the definition of class ExecuteInterface
+#include "utils.h"
+
+class DragnDropContainer;
+class SourceFileEntry;
 
 class QDVDAuthorInit
 {
 private:
 	class MenuBlock {
 		public:
+			class SubBlock;
 			class Block
 			{
 				public:
-				Block ()
-					{ iDefaultCommand = 0; iBlockID = -1; };
+				 Block ()
+					{ iDefaultCommand = 0; iBlockID = -1; iActive = -1; bHidden = false; bEditable = true;};
+				~Block ()
+					{ for (uint t=0;t<listSubBlocks.count();t++) delete listSubBlocks[t]; };
 				QString     qsBlockTag;
+				int         iActive;
 				int         iBlockID;
 				int         iDefaultCommand;
+				bool        bHidden;
+				bool        bEditable;
 				QStringList listComments;
 				QStringList listCommands;
+				QValueList<SubBlock *>listSubBlocks;
+			};
+			class SubBlock
+			{
+				public:
+				 SubBlock () { iNumber=0; };
+				~SubBlock () { for (uint t=0;t<listBlocks.count();t++) delete listBlocks[t];};
+				QString     qsName;	// Name. E.g. Transcode
+				int         iNumber;	// running number starting from 0. In case we need to sort it.
+				QValueList<Block *>listBlocks;
 			};
 			MenuBlock ();
 
-			QString qsMenuTag;
-			bool    bValid;
-			bool    bHidden;
-			QString qsBlockName;
+			QString qsMenuTag;      // Holds the ID to indicate which MenuBlock it is (E.g. TAG_CONVERT).
+			bool    bValid;         // 
+			bool    bHidden;        // Should this MenuBlock be hidden initially ?
+			QString qsBlockName;    // The name of the MenuBlock (E.g. Main Menu VMGM (widthxheight))
 			QColor  colorBackground;
 
 			Block   blockMovieBackground;
@@ -66,55 +124,94 @@ private:
 			Block   blockSpumux;
 			Block   blockOthers;
 	};
+
 public:
 	 QDVDAuthorInit ();
-	 QDVDAuthorInit (QString, QString, QString);
+	 QDVDAuthorInit (DragNDropContainer *);
+	 QDVDAuthorInit (QValueList<Utils::toolsPaths *>&, DragNDropContainer *);
 	~QDVDAuthorInit ();
 
-	QValueList <ExecuteInterface *>&getList();
+	QString preferredEngine ();
+	bool    visibleRegion   ();
+	void setToolsPaths (QValueList<Utils::toolsPaths *>&);
+	QValueList <Utils::toolsPaths *> &getToolsPaths    ();
+	QValueList <ExecuteInterface *>  &getList          ();
+	QStringList                       getHistory       ();
+	QValueList<QPixmap *>             getHistoryPix    ();
+	int                               maxHistoryFiles  ();
+	int                               getAutosave      ();
+	QString                           getStyle         ();
+	void setStyle            (QString);
+	void setAutosave         (int);
+	void setVisibleRegion    (bool);
+	void setHistory          (int, QStringList, QValueList<QPixmap *>);
 	void appendPreProcessing ();
-	void appendMenu (DVDMenu *, QString, QString);
-	void appendPostProcessing ();
-	bool readIniFile ();
-	bool saveIniFile ();
-	void setDefault (int, uint);
-	QDVDAuthorInit::MenuBlock::Block *getBlock (int);
-	QString resolvString  (QString);
-	void setKeywords (QValueList<QString>);
+	void appendConvert       (SourceFileEntry *);
+	void appendMenu          (DVDMenu *, QString, QString);
+	void appendPostProcessing();
+	bool readIniFile         ();
+	bool saveIniFile         ();
+	void setDefault          (int, uint);
+	QDVDAuthorInit::MenuBlock::Block *getBlock ( int );
+//	QString resolvTranscodingString        ( QString );
+	QString resolvString                   ( QString );
+	QString resolvConvert           (QString, QString);
+	void setKeywords            (QValueList <QString>);
+	QStringList getKeys           (MenuBlock::Block *);
 
 private:	// private functions.
 	bool    initMe ();
-	void    addBlock(ExecuteInterface *, MenuBlock::Block *);
-	bool    readBlock (MenuBlock::Block *, QDomElement *);
+	void    addBlock      (ExecuteInterface *, MenuBlock::Block *);
+	bool    readBlock     (MenuBlock::Block *, QDomElement *);
+	bool    readSubBlock  (MenuBlock::SubBlock *, QDomElement *pElem);
 	bool    readMenuBlock (MenuBlock *, QDomElement *);
 	bool    saveMenuBlock (MenuBlock *, QDomElement *);
-	bool    saveBlock (MenuBlock::Block *, QDomElement *);
+	bool    saveBlock     (MenuBlock::Block *, QDomElement *);
+	bool    saveSubBlock  (MenuBlock::SubBlock *, QDomElement *);
+	int     printBlock    (MenuBlock::Block *, int i=0);
+//	bool    saveSubBlock (MenuBlock::Block *, QDomElement *, bool);
 	QString convertSoundFile (QString);
 	void    resetInitFile ();
+	void    mergeToolsPaths (QValueList<Utils::toolsPaths *>);
 
 private:	// private variables
+	QString              m_qsPreferredEngine;
+	bool                 m_bVisibleRegion;
+	bool                 m_bProtectToolsObjects;
 	int                  m_iCurrentBlockID;
 	QString              m_qsTempPath;
+	QString              m_qsStyle;
 	QString              m_qsProjectPath;
-	QString              m_qsDvdauthor;
+	QString              m_qsDvdauthorFile;
 	QStringList          m_listKeywords;
 	QValueList<QColor *> m_arrayColors;
 	int                  m_iColorCounter;
+	MenuBlock            m_convertMenuBlock;
 	MenuBlock            m_palMenuBlock;
 	MenuBlock            m_ntscMenuBlock;
 	MenuBlock            m_dvdauthorMenuBlock;
 	MenuBlock            m_burningMenuBlock;
+	QStringList          m_listHistory;	   // History Project files ...
+	QValueList<QPixmap *>m_listHistoryPix;	   // History Project file Icons ...
+	bool                 m_bOwnerOfHistoryPix; // indicates if we have ownership and thus should delete the objects at exit ...
+	int                  m_iMaxHistoryFiles;
+	int                  m_iAutosave;
 	QStringList          m_soundList;
-
+	QStringList          m_listKeys;
+	QStringList          m_listTranscodeKeys;
 	// Pre processing steps
-	// ... nothing thus far ...
+	ExecuteInterface m_convertInterface;
 
 	// Post processing steps
 	ExecuteInterface m_dvdauthorInterface;
 	ExecuteInterface m_burnInterface;
 
-	// THe full list of commands to execute ...
-	QValueList <ExecuteInterface *>m_listExecute;
+	// The full list of commands to execute ...
+	QValueList <ExecuteInterface *>  m_listExecute;
+	QValueList <ExecuteInterface *>  m_listToBeDeleted;
+	QValueList <Utils::toolsPaths *> m_listToolsPaths;
+	DragNDropContainer              *m_pDragNDropContainer;
+	
 	friend class DialogCommandEditor;
 	friend class DialogExecute;
 };
@@ -129,6 +226,7 @@ XML
 	+FORMAT+               = "PAL" or "NTSC"
 	+MENU_NAME+            = E.g. Main Menu VMGM
 	+BACKGROUND_FILE_NAME+ = E.g. Main Menu VMGMbackground.jpg
+	+BACKGROUND_FULL_NAME+ = E.g. /tmp/Unnamed/Main Menu VMGMbackground.jpg
 	+TEMP_PATH+            = E.g. /tmp
 	+SOUND_LIST+           = All sound files in mp2 format (including \" - characters !)
 	                         E.g. \"sound1.mp2\" \"sound2.mp2\"
@@ -162,6 +260,23 @@ Following is the default init file ...
   <Color number="9">#8FEED3</Color>
   <Color number="10">#E0EE8F</Color>
   <Color number="11">#F92F5E</Color>
+  <ExecuteInterface>
+    <Convert blockname="Convert" color="#F92F5E">
+      <Block name="MOVIE_CONVERT">
+        <Comment><p align=\"center\">This will convert the input movie file from DV - format into DVD conform material.</p></Comment>
+        <Command>transcode -i mindfields_low_osx.avi -x ffmpeg -V -w 8500 --encode_fields b --export_asr 2 -F 8,-c -q 6 -4 2 -2 1 -N 0.5 -E -10 -K tmpgenc -R 2 -y mpeg2enc,mp2enc -b 224 -m mindfields_out_dvd.mpg -o mindfields_out_dvd.mpg --print_status 10</Command>
+        <Comment><p align=\"center\">This will convert the input movie file from mpeg1 - format into DVD conform material.</p></Comment>
+        <Command>transcode -i mindfields_low_osx.avi -x ffmpeg -V -w 8500 --encode_fields b --export_asr 2 -F 8,-c -q 6 -4 2 -2 1 -N 0.5 -E -10 -K tmpgenc -R 2 -y mpeg2enc,mp2enc -b 224 -m mindfields_out_dvd.mpg -o mindfields_out_dvd.mpg --print_status 10</Command>
+      </Block>
+      <Block name="AUDIO_CONVERT">
+        <Comment><p align=\"center\">We need to convert from OGG-Vorbis format to mp2.</p></Comment>
+        <Command>oggdec test.ogg -o - | mp2enc -o test2.mp2</Command>
+        <Comment><p align=\"center\">We need to convert from mp3 format to mp2.</p></Comment>
+        <Command>lame --decode blues.mp3 - | mp2enc -o blues.mp2</Command>
+        <Command>mplayer mymusicfile.mp3 -vo null -ao pcm -aofile menu_audio.pcm ; mp2enc -r 48000 -o menu_audio.mpa &lt; menu_audio.pcm</Command>
+      </Block>
+    </Convert>
+  </ExecuteInterface>
   <ExecuteInterface>
     <Pal blockname="+MENU_NAME+ (PAL +WIDTH+x+HEIGHT+)" color="#9EEE81">
       <Block name="MOVIE_BACKGROUND">
