@@ -91,7 +91,7 @@ bool CXmlSlideshow::readXml (QString &fileName)
 	//////////////////////////////////////////////////////////////////////////////////
 	// Assign the file
 	QFile projectFile(fileName);
-	if (!projectFile.open(IO_Raw | IO_ReadWrite))
+	if (!projectFile.open(IO_ReadWrite))
 		return false;
 
 	QDomDocument xmlDoc( SLIDESHOW_DOCTYPE );
