@@ -21,44 +21,78 @@
 **
 ****************************************************************************/
 #include <stdlib.h>
+#include <unistd.h>
 
+#include <qapplication.h>
 #include <qmainwindow.h>
-#include <qlistbox.h>
-#include <qlistview.h>
-#include <qpopupmenu.h>
 #include <qfiledialog.h>
 #include <qmessagebox.h>
 #include <qpushbutton.h>
+#include <qpopupmenu.h>
+#include <qlistview.h>
 #include <qdockarea.h>
+#include <qlistbox.h>
+#include <qcursor.h>
+#include <qheader.h>
 
+//#include "../bugs_workaround.h"
 #include "global.h"
 #include "sourcetoolbar.h"
 #include "dialogslide.h"
 #include "qdvdauthor.h"
+#include "listviewmedia.h"
+#include "listviewitemmedia.h"
+#include "dvdmenuundoobject.h"
+#include "menupreview.h"
 #include "dialogmovie.h"
-#include "listboxcolortext.h"
-#include "qplayer/xineinfo.h"
 
+#include "qplayer/mediainfo.h"
+#include "qplayer/mediacreator.h"
+//#include "qplayer/dialogchapters.h"
+#include "qplayer/sourcefiledialog.h"
+
+#define SOURCE_FILE_ENTRY_ID   0
+#define SOURCE_FILE_ENTRY_NAME 1
 
 SourceToolBar::SourceToolBar (const QString &qsLabel, QMainWindow *pMainWindow, QWidget *pParent, bool bNewLine, const char *pName, WFlags f)
 	: QToolBar (qsLabel, pMainWindow, pParent, bNewLine, pName, f)
 {
+	m_pMediaInfo = NULL;
 	m_pDVDAuthor = (QDVDAuthor *)pMainWindow;
+
+	// Next is to create a MediaEngine in a separate thread to keep the application running and not stottering ...
+	m_pMediaInfo = MediaCreator::createInfo ();
+
 	setResizeEnabled (true);
 	setMovingEnabled (true);
 	pMainWindow->addDockWindow (this, Left);
 	m_pSourceWidget = new uiSourceWidget (this);
-	m_pSourceWidget->m_pListBoxAllSources->clear ();
-	m_pSourceWidget->m_pListBoxAllSources->setColumnMode(QListBox::FixedNumber); //FitToWidth);
+
+	QGridLayout *tabLayout = new QGridLayout(m_pSourceWidget->tab, 1, 1, 4, 4, "tabLayout");
+	m_pListViewAllSources  = new ListViewMedia (m_pSourceWidget->tab, "m_pListViewAllSources" );
+	tabLayout->addWidget( m_pListViewAllSources, 0, 0 );
+	m_pListViewAllSources->clear ();
+//	m_pListViewAllSources->setPaletteBackgroundColor (QColor(111,200,255));
+	m_pListViewAllSources->header()->hide();
+	m_pListViewAllSources->addColumn (QString("[Nr]") );
+	m_pListViewAllSources->addColumn (QString ("Name"));
+	m_pListViewAllSources->addColumn (QString ("")    );
+	m_pListViewAllSources->setRootIsDecorated(true);
+	m_pListViewAllSources->allColumnsShowFocus();
+
 	m_pSourceWidget->m_pListViewVideoSources->clear ();
 	m_pSourceWidget->m_pListViewAudioSources->clear ();
 
-	connect( m_pSourceWidget->m_pListBoxAllSources, SIGNAL( mouseButtonClicked(int,QListBoxItem*,const QPoint&)), this, SLOT(slotClickedOnVideoList(int,QListBoxItem*,const QPoint&) ) );
-//	connect( m_pSourceWidget->m_pListViewVideoSources, SIGNAL( mouseButtonClicked(int,QListBoxItem*,const QPoint&)), this, SLOT(slotClickedOnVideoList(int,QListBoxItem*,const QPoint&) ) );
-//	connect( m_pSourceWidget->m_pListViewAudioSources, SIGNAL( mouseButtonClicked(int,QListBoxItem*,const QPoint&)), this, SLOT(slotClickedOnVideoList(int,QListBoxItem*,const QPoint&) ) );
+	connect( m_pListViewAllSources, SIGNAL( doubleClicked ( QListViewItem *, const QPoint &, int )), this, SLOT (slotDoubleClickedOnVideoList(QListViewItem *, const QPoint &, int)) );
+	connect( m_pListViewAllSources, SIGNAL( rightButtonClicked ( QListViewItem *, const QPoint &, int )), this, SLOT (slotRightClickedOnVideoList (QListViewItem *, const QPoint &, int)) );
+	connect( m_pListViewAllSources, SIGNAL( clicked ( QListViewItem *, const QPoint &, int )), this, SLOT (slotClickedOnVideoList      (QListViewItem *, const QPoint &, int)) );
+	connect (m_pListViewAllSources, SIGNAL(signalRemoveEntry (SourceFileEntry *)), this, SLOT(slotRemoveEntry (SourceFileEntry *)));
 
 	connect ( m_pSourceWidget->m_pButtonAddMovie, SIGNAL(clicked()), this, SLOT(slotAddMovie()));
 	connect ( m_pSourceWidget->m_pButtonAddSlide, SIGNAL(clicked()), this, SLOT(slotAddSlideshow()));
+
+//	connect( m_pSourceWidget->m_pListViewVideoSources, SIGNAL( mouseButtonClicked(int,QListBoxItem*,const QPoint&)), this, SLOT(slotClickedOnVideoList(int,QListBoxItem*,const QPoint&) ) );
+//	connect( m_pSourceWidget->m_pListViewAudioSources, SIGNAL( mouseButtonClicked(int,QListBoxItem*,const QPoint&)), this, SLOT(slotClickedOnVideoList(int,QListBoxItem*,const QPoint&) ) );
 }
 
 SourceToolBar::~SourceToolBar ()
@@ -67,6 +101,8 @@ SourceToolBar::~SourceToolBar ()
 	for (t=0;t<m_listSourceFileEntries.count();t++)
 		delete m_listSourceFileEntries[t];
 	m_listSourceFileEntries.clear();
+	if (m_pMediaInfo)
+		delete m_pMediaInfo;
 }
 
 QSize SourceToolBar::sizeHint () const
@@ -92,6 +128,27 @@ QString SourceToolBar::convertFileSize(uint iFileSize)
 	return qsReturn;
 }
 
+void *SourceToolBar::getMediaEngine ()
+{
+	static int iCounter = 0;
+	while (!m_pMediaInfo)	{
+		// Init does not seem to have finished yet ...
+		// So we wait for a second ...
+		sleep (1);
+		// this counter will break out of the loop after 5 unsuccessfull seconds
+		if (iCounter ++ > 5)
+			return NULL;
+	}
+	return m_pMediaInfo->getMediaEngine ();
+}
+
+MediaInfo *SourceToolBar::getMediaInfo ()
+{
+	// This is just to ensure we have a engine already created ...
+	getMediaEngine ();
+	return m_pMediaInfo;
+}
+
 int SourceToolBar::sourceFileCount()
 {
 	return (int)m_listSourceFileEntries.count();
@@ -102,19 +159,65 @@ SourceFileEntry *SourceToolBar::sourceFileEntry(uint iEntryNumber)
 	return m_listSourceFileEntries[iEntryNumber];
 }
 
+SourceFileEntry *SourceToolBar::getCurrentSourceFileEntry ()
+{
+	SourceFileEntry *pSourceFileEntry = NULL;
+
+	ListViewItemMedia *pItem = (ListViewItemMedia *)m_pListViewAllSources->currentItem();
+	if (!pItem)
+		return NULL;
+	pSourceFileEntry = pItem->sourceFileEntry ();
+	// If the SourceFileEntry is NULL then we have a SourceFileInfo and
+	// thus get the SourceFileEntry from the  parent item ..
+	if (!pSourceFileEntry)
+		 pSourceFileEntry = ((ListViewItemMedia *)pItem->parent())->sourceFileEntry();
+	return pSourceFileEntry;
+}
+
+SourceFileInfo *SourceToolBar::getCurrentSourceFileInfo ()
+{
+	SourceFileInfo  *pSourceFileInfo  = NULL;
+	SourceFileEntry *pSourceFileEntry = NULL;
+
+	ListViewItemMedia *pItem = (ListViewItemMedia *)m_pListViewAllSources->currentItem();
+	if (!pItem)
+		return NULL;
+	pSourceFileInfo  = pItem->sourceFileInfo  ();
+	// If the Info is NULL then we have a header and want the first FileInfo of it ...
+	if (!pSourceFileInfo)	{
+		pSourceFileEntry = pItem->sourceFileEntry ();
+		pSourceFileInfo = pSourceFileEntry->listFileInfos[0];
+	}
+	return pSourceFileInfo;
+}
+/*
 SourceFileEntry *SourceToolBar::getCurrentSourceFileEntry()
 {
 	// This function will return the currently selected source file entry ...
 	uint t;
-	QString qsCurrentText = m_pSourceWidget->m_pListBoxAllSources->currentText();
+	QString qsCurrentText;
+	QListViewItem *pCurrentItem = m_pListViewAllSources->currentItem();
+	if (pCurrentItem)
+		qsCurrentText = pCurrentItem->text(SOURCE_FILE_ENTRY_NAME);
 	for (t=0;t<m_listSourceFileEntries.count();t++)	{
 		if (m_listSourceFileEntries[t]->qsDisplayName == qsCurrentText)
 			return m_listSourceFileEntries[t];
 	}
 	return NULL;
 }
+*/
+void SourceToolBar::slotDoubleClickedOnVideoList(QListViewItem *pItem, const QPoint &, int)
+{
+	// First we check if the item is valid ...
+	if (pItem == NULL)	{
+		slotAddMovie ();
+		return;
+	}
+	if (m_listSourceFileEntries.count() > 0)
+		slotEditMovie    ();
+}
 
-void SourceToolBar::slotClickedOnVideoList(int iButton, QListBoxItem *pItem, const QPoint &thePoint)
+void SourceToolBar::slotRightClickedOnVideoList (QListViewItem *pItem, const QPoint &thePoint, int)
 {
 	// First we check if the item is valid ...
 	if (pItem == NULL)	{
@@ -122,79 +225,148 @@ void SourceToolBar::slotClickedOnVideoList(int iButton, QListBoxItem *pItem, con
 		return;
 	}
 	// here we handle the movie - right click ...
-	if (iButton == Qt::RightButton)	{
-		// Here we pop open the properties dialog for the movie, where you can set
-		// o size of movie (resizing tool used = ???
-		// o Define Title # / Add Chapters to Title
-		
-		// Here we find out if we can actually play the file ... Meaning slideshows can not be played !!!
-		uint t;
-		bool bShow = true;
-		for (t=0;t<m_listSourceFileEntries.count();t++)	{
-			if (pItem->text() == m_listSourceFileEntries[t]->qsDisplayName)	{
-				if (m_listSourceFileEntries[t]->bIsSlideshow)
-					bShow = false;
-				break;
-			}
+	// Here we pop open the properties dialog for the movie, where you can set
+	// o size of movie (resizing tool used = ???
+	// o Define Title # / Add Chapters to Title
+
+	// Here we find out if we can actually play the file ... Meaning slideshows can not be played !!!
+	uint t;
+	bool bShow = true;
+	for (t=0;t<m_listSourceFileEntries.count();t++)	{
+		if (pItem->text(SOURCE_FILE_ENTRY_NAME) == m_listSourceFileEntries[t]->qsDisplayName)	{
+			if (m_listSourceFileEntries[t]->bIsSlideshow)
+				bShow = false;
+			break;
 		}
-
-		QPopupMenu *pMenu = new QPopupMenu(m_pSourceWidget->m_pListBoxAllSources);
-		if (bShow)
-			pMenu->insertItem ( tr ("Play"), this, SLOT(slotPlayMovie()));
-		pMenu->insertItem ( tr ("Edit ...")    , this, SLOT(slotEditMovie()));
-		pMenu->insertItem ( tr ("Convert ...") , this, SLOT(slotConvertMovie()));
-		pMenu->insertItem ( tr ("Delete")      , this, SLOT(slotDeleteSource()));
-		pMenu->exec(thePoint);
 	}
-	else {
 
-	}
-	return;
+	QPopupMenu *pMenu = new QPopupMenu(m_pListViewAllSources);
+	if (bShow)
+		pMenu->insertItem ( tr ("Play")    , this, SLOT(slotPlayMovie    ()));
+	pMenu->insertItem ( tr ("Properties ...")    , this, SLOT(slotEditMovie    ()));
+	pMenu->insertItem ( tr ("Delete")      , this, SLOT(slotDeleteSource ()));
+	pMenu->exec(thePoint, 2);
+	
+	delete pMenu;
 }
 
+void SourceToolBar::slotClickedOnVideoList(QListViewItem *pItem, const QPoint &thePoint, int)
+{
+	// If no Item was clicked the the user might want to add something ?
+	if (pItem == NULL)	{
+		// Here we translate the clicked position to idget coordinates
+		QPoint p (m_pListViewAllSources->mapFromGlobal(thePoint));
+		// and since we actually are only looking for a hight comparison,
+		// we set x to always hit a entry (if there is one).
+		p.setX(50);
+		if (!m_pListViewAllSources->itemAt (p))
+			slotAddMovie ();
+	}
+}
+
+// This is without background task to get the info ...
 void SourceToolBar::slotAddMovie()
 {
-	uint t;
+	if (!m_pDVDAuthor->checkForNewProject ())
+		return;
 	// Some one clicked the "Add Movie" button.
 	QString qsFilter = m_pDVDAuthor->getMovieFilter();
 	QStringList listAddMovies = QFileDialog::getOpenFileNames (tr("Movie Files (")+qsFilter+QString (")"), m_pDVDAuthor->currentPath(), this, tr("Open file dialog"), tr ("Add To Project ..."));
-
+	// I tried to get the sorting of the names out of here but
+	// detailViewSelectionChanged and listBoxSelectionChanged
+	// are not flexible enough to handle this (yet).
 	if (listAddMovies.count() < 1)
 		return;
+
+	addMovieList (listAddMovies);
+}
+
+void SourceToolBar::addMovieList (QStringList &listAddMovies, QString *pTitle)
+{
+	uint t;
 	QFileInfo fileInfo (listAddMovies[0]);
 	QString qsPath = fileInfo.filePath();
-	m_pDVDAuthor->setCurrentPath( qsPath );
+	Global::qsCurrentPath = qsPath;
 
-	// Lets create a new SoourceFileEntry ...
-	XineInfo *pXineInfo = new XineInfo (m_pDVDAuthor->getXineEngine());
+	QCursor myCursor (QCursor::WaitCursor);
+	QApplication::setOverrideCursor (myCursor);
 	SourceFileEntry *pEntry = new SourceFileEntry;
+	pEntry->sizeThumbnail = m_pDVDAuthor->getDragNDropContainer()->sizeThumbnail;
 	pEntry->bSoundSource = false;
 	SourceFileInfo *pInfo;
 	for (t=0;t<listAddMovies.count();t++)	{
 		pInfo = new SourceFileInfo;
-		pXineInfo->setStream(listAddMovies[t]);
-
-		pInfo->qsFormat     = pXineInfo->getFormat (true);
-		pInfo->qsResolution = pXineInfo->getResolutionString ();
-		pInfo->qsLength     = pXineInfo->getLengthString ();
-		pInfo->qsSize       = pXineInfo->getSizeString();
-		pInfo->qsRatio      = pXineInfo->getRatio ();
-		pInfo->qsFPS        = QString ("%1").arg(pXineInfo->getFPS());
-		pInfo->qsStatus     = pXineInfo->getStatus();
 		pInfo->qsFileName   = listAddMovies[t];
+		// Here we generate a dummy image as a place holder
+		pInfo->pPreview = new QImage (QImage::fromMimeSource( "please_wait.jpg" ));
+		*pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
+		// and then register to obtain the info in the background.
+		MediaCreator::registerWithMediaScanner (this, pInfo);
 
 		pEntry->listFileInfos.append(pInfo);
 	}
-	if (listAddMovies.count () > 1)	{
+
+	if (pTitle)	{	// If a title has been 
+		pEntry->qsDisplayName = *pTitle;
+	}
+	else if (listAddMovies.count () > 1)	{
 		QString qsText = tr(" Movie Files>");
-		pEntry->qsDisplayName.sprintf ("[%02d] - <%02d", getFreeSourceSlot (), listAddMovies.count()) + qsText;	//fileInfo.fileName();
+		pEntry->qsDisplayName.sprintf ("[%02d] - <%02d", getFreeSourceSlot (), (int)listAddMovies.count());
+		pEntry->qsDisplayName += qsText;
 	}
 	else
-		pEntry->qsDisplayName.sprintf ("[%02d] - %s", getFreeSourceSlot (), (const char *)fileInfo.fileName());
+		pEntry->qsDisplayName.sprintf ("[%02d] - %s", getFreeSourceSlot (), (const char *)fileInfo.baseName(true));
 	m_listSourceFileEntries.append(pEntry);
 	// Okay, now we should also add this into the list box ...
-	delete pXineInfo;
 	addMovie (pEntry);
+	QApplication::restoreOverrideCursor ();
+}
+
+void SourceToolBar::timerEvent(QTimerEvent *pTimerEvent)
+{
+	// Called after the background thread has generated the preview ...
+	uint t, i;
+	SourceFileEntry *pEntry = NULL;
+	SourceFileInfo  *pInfo  = NULL;
+	switch ( pTimerEvent->timerId() )	{
+	case MEDIASCANNER_EVENT:
+		// We could simply call this function but it would be a brute force approach as the whole tree would get rebuild.
+		//refreshToolBarEntries ();
+		// So rather we check all SourceFIleInfo's for the flag bUpdateImage and do so singularily.
+		for (t=0;t<m_listSourceFileEntries.count();t++)	{
+			pEntry = m_listSourceFileEntries[t];
+			for (i=0;i<pEntry->listFileInfos.count();i++)	{
+				// Okay found the SourceFileInfo no we need the ListViewItemMedia - object for this Info.
+				pInfo = pEntry->listFileInfos[i];
+				if (pInfo->bUpdateInfo)	{
+					ListViewItemMedia *pChild = (ListViewItemMedia *)m_pListViewAllSources->firstChild ();
+					while (pChild)	{
+						// Got it and it fits ...
+						pChild->replaceInfo(pInfo);
+						pChild = (ListViewItemMedia *)pChild->nextSibling();
+					}
+					// Oh and the ListViewVideoSources should also be updated ...
+					QListViewItem *pItem = m_pSourceWidget->m_pListViewVideoSources->firstChild ();
+					while (pItem)	{
+						if (pItem->text (7) == pInfo->qsFileName)	{
+							pItem->setText (0, pInfo->qsFormat);
+							pItem->setText (1, pInfo->qsResolution);
+							pItem->setText (2, pInfo->qsLength);
+							pItem->setText (3, pInfo->qsSize);
+							pItem->setText (4, pInfo->qsRatio);
+							pItem->setText (5, pInfo->qsFPS);
+							pItem->setText (6, pInfo->qsStatus);
+						}
+						pItem = pItem->nextSibling();
+					}
+					pInfo->bUpdateInfo = false;
+					m_pDVDAuthor->slotCalculateSize();
+					return;
+				}
+			}
+		}
+	break;
+	}
 }
 
 int SourceToolBar::getFreeSourceSlot ()
@@ -231,8 +403,6 @@ void SourceToolBar::addMovie (SourceFileEntry *pEntry)
 	uint t;
 	QColor statusColor (COLOR_MOVIE_FILES_OK);
 
-	// And further on to the m_pListViewVideoSources ...
-	ListBoxColorText *pListBoxItem;
 	SourceFileInfo *pInfo;
 	for (t=0;t<pEntry->listFileInfos.count();t++)	{
 		pInfo = pEntry->listFileInfos[t];
@@ -244,42 +414,48 @@ void SourceToolBar::addMovie (SourceFileEntry *pEntry)
 			pInfo->qsResolution, pInfo->qsLength, pInfo->qsSize, pInfo->qsRatio,
 			pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName);
 	}
-	pListBoxItem = new ListBoxColorText (pEntry->qsDisplayName, statusColor);
-	m_pSourceWidget->m_pListBoxAllSources->insertItem(pListBoxItem);
+	new ListViewItemMedia (m_pListViewAllSources, pEntry, statusColor);
 }
 
 void SourceToolBar::appendSourceFileEntry(SourceFileEntry *pEntry)
 {
 	// This function is called when loading from an XML-project file ???
-
 	m_listSourceFileEntries.append(pEntry);
-
-	ListBoxColorText *pListBoxItem;
-	QColor statusColor (COLOR_MOVIE_FILES_OK);
-	
-//	if (pEntry->listFileInfos[0]->qsSample.isEmpty())	{	// Here we handle a Movie SourceFileEntry ...
+	QColor statusColor (COLOR_MOVIE_FILES_BAD);
+	// Here we set the preview size ...
+	pEntry->sizeThumbnail = m_pDVDAuthor->getDragNDropContainer()->sizeThumbnail;
 	if (!pEntry->bSoundSource)	{	// Here we handle a Movie SourceFileEntry ...
 		for (uint t=0;t<pEntry->listFileInfos.count();t++)	{
-			if (pEntry->listFileInfos[t]->qsStatus != QString ("Ok"))
-				statusColor = QColor (COLOR_MOVIE_FILES_BAD);
-		
 			SourceFileInfo *pInfo = pEntry->listFileInfos[t];
+			// Add the plaeas - wait image
+			pInfo->pPreview = new QImage (QImage::fromMimeSource( "please_wait.jpg" ));
+			// and the request the preview from a background thread.
+			MediaCreator::registerWithMediaScanner (this, pInfo);
+			*pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
+			// And show what we have thus far.
 			new QListViewItem (m_pSourceWidget->m_pListViewVideoSources, pInfo->qsFormat, pInfo->qsResolution, pInfo->qsLength,  pInfo->qsSize, pInfo->qsRatio, pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName);
 		}
 	}
 	else	{	// And here we have a Sound SourceFileEntry
 		statusColor = QColor (COLOR_SOUND_FILES_OK);
-	
+
 		for (uint t=0;t<pEntry->listFileInfos.count();t++)	{
-			if (pEntry->listFileInfos[t]->qsStatus != QString ("Ok"))
-				statusColor = QColor (COLOR_SOUND_FILES_BAD);
-		
 			SourceFileInfo *pInfo = pEntry->listFileInfos[t];
-			new QListViewItem (m_pSourceWidget->m_pListViewAudioSources, pInfo->qsFormat, pInfo->qsLength, pInfo->qsBits, pInfo->qsSample, pInfo->qsBPS, pInfo->qsSize,  pInfo->qsStatus, pInfo->qsFileName);
+			if (pInfo->qsStatus != QString ("Ok"))
+				statusColor = QColor (COLOR_SOUND_FILES_BAD);
+
+			pInfo->pPreview = new QImage (QImage::fromMimeSource( "sound_file.jpg" ));
+			*pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
+			new QListViewItem (m_pSourceWidget->m_pListViewAudioSources, pInfo->qsFormat, pInfo->qsLength, pInfo->qsBits, pInfo->qsSample, pInfo->qsBPS, pInfo->qsSize, pInfo->qsStatus, pInfo->qsFileName);
 		}
 	}
-	pListBoxItem = new ListBoxColorText (pEntry->qsDisplayName, statusColor);
-	m_pSourceWidget->m_pListBoxAllSources->insertItem(pListBoxItem);	
+//	makeScreenshots (pEntry);
+	new ListViewItemMedia (m_pListViewAllSources, pEntry, statusColor);
+}
+
+void SourceToolBar::slotRemoveEntry(SourceFileEntry *pEntry)
+{
+	m_listSourceFileEntries.remove(pEntry);
 }
 
 void SourceToolBar::slotAddSound()
@@ -303,29 +479,32 @@ void SourceToolBar::addSound (QStringList &listSoundNames)
 
 	// And here we set the  current Directory for the application ...
 	QString qsPath = fileInfo.filePath();
-	m_pDVDAuthor->setCurrentPath( qsPath );
+	Global::qsCurrentPath = qsPath;
 
 	// Before we insert it we should remove all previous entries so that we hold only one entry for one sound file
 	removeEntry (qsFileName);
 
-	XineInfo *pXineInfo = new XineInfo (m_pDVDAuthor->getXineEngine ());
+	MediaInfo *pMediaInfo = MediaCreator::createInfo (getMediaEngine());
 	QColor statusColor (COLOR_SOUND_FILES_OK);
 	SourceFileInfo  *pInfo;
 	SourceFileEntry *pEntry = new SourceFileEntry;
 	pEntry->bSoundSource = true;
+	pEntry->sizeThumbnail = m_pDVDAuthor->getDragNDropContainer()->sizeThumbnail;
 	for (t=0;t<listSoundNames.count();t++)	{
-		pXineInfo->setStream (listSoundNames[t]);
+		pMediaInfo->setFileName (listSoundNames[t]);
 		// Lets create a new SoourceFileEntry for this sound file ...
 		pInfo = new SourceFileInfo;
 
-		pInfo->qsSize     = pXineInfo->getSizeString();
-		pInfo->qsBits     = QString ("%1").arg(pXineInfo->getBits());
-		pInfo->qsSample   = pXineInfo->getSampleString ();
-		pInfo->qsBPS      = pXineInfo->getBPSString (false);
-		pInfo->qsLength   = pXineInfo->getLengthString ();
-		pInfo->qsFormat   = pXineInfo->getFormat (false);
-		pInfo->qsStatus   = pXineInfo->getStatus();
+		pInfo->qsSize     = pMediaInfo->getSizeString();
+		pInfo->qsBits     = QString ("%1").arg(pMediaInfo->getBits());
+		pInfo->qsSample   = pMediaInfo->getSampleString ();
+		pInfo->qsBPS      = pMediaInfo->getBPSString (false);
+		pInfo->qsLength   = pMediaInfo->getLengthString ();
+		pInfo->qsFormat   = pMediaInfo->getFormat (false);
+		pInfo->qsStatus   = pMediaInfo->getStatus();
 		pInfo->qsFileName = listSoundNames[t];
+		pInfo->pPreview   = new QImage (QImage::fromMimeSource( "sound_file.jpg" ));
+		*pInfo->pPreview  = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
 
 		if (pInfo->qsStatus != QString ("Ok"))
 			statusColor = QColor (COLOR_SOUND_FILES_BAD);
@@ -334,44 +513,68 @@ void SourceToolBar::addSound (QStringList &listSoundNames)
 	}
 	if (listSoundNames.count () > 1)	{
 		QString qsText = tr(" Sound Files>");
-		pEntry->qsDisplayName.sprintf ("[%02d] - <%02d", getFreeSourceSlot (), listSoundNames.count()) + qsText;
+		pEntry->qsDisplayName.sprintf ("[%02d] - <%02d", getFreeSourceSlot (), (int)listSoundNames.count()) + qsText;
 	}
 	else
 		pEntry->qsDisplayName.sprintf ("[%02d] - %s",getFreeSourceSlot (), (const char *)fileInfo.fileName());
 	m_listSourceFileEntries.append(pEntry);
 
-	// And finally we add it to the list ...
-	ListBoxColorText *pListBoxItem;
-	pListBoxItem = new ListBoxColorText (pEntry->qsDisplayName, statusColor);
-	m_pSourceWidget->m_pListBoxAllSources->insertItem(pListBoxItem);
+	// this new sound is assigned to the current DVDMenu's Preview. PHew what a long list to get there ...
+	m_pDVDAuthor->getCurrentSubMenu()->getMenuPreview()->undoBuffer()->push (new DVDMenuUndoObject(DVDMenuUndoObject::NEW_AUDIO, pEntry ));	// And finally we add it to the list ...
+	new ListViewItemMedia (m_pListViewAllSources, pEntry, statusColor);
 
 	// And further on to the m_pListViewVideoSources ...
 	new QListViewItem (m_pSourceWidget->m_pListViewAudioSources, pInfo->qsFormat, pInfo->qsLength, pInfo->qsBits, pInfo->qsSample, pInfo->qsBPS, pInfo->qsSize,  pInfo->qsStatus, pInfo->qsFileName);
-	delete pXineInfo;
+	delete pMediaInfo;
 }
 
 void SourceToolBar::slotAddSlideshow()
 {
+	Utils theUtil;
 printf ("SourceToolBar::slotAddSlideshow\n");
+	if (!m_pDVDAuthor->checkForNewProject ())
+		return;
 	// First we pop up the slideshow generation dialog box
-	QString qsTempPath = m_pDVDAuthor->getTempFile(QString ());
+	QString qsTempPath = theUtil.getTempFile(QString ());
 	CSlideDialog *pSlideDialog = new CSlideDialog;
 	pSlideDialog->initMe(this, qsTempPath);
 	pSlideDialog->show();
 	// Note that the SourceFileEntry is generated  when we have given a name to the
 	// newly generated slideshow. This is then done SourceToolBar::slotAddSlideshow(QString);
+	
+	// FIXME: 
+	// How do we free the resources of this dialog after it has finished ?
 }
 
-
 void SourceToolBar::slotEditMovie()
 {
 	// Here we open the MovieDialog.
-	// Note: The preview depends on the same class as
-	// the main QXineWidget in QXine, thus please
-	// give some time to wrap up development ...
+	ListViewItemMedia *pItem = (ListViewItemMedia *)m_pListViewAllSources->currentItem();
+	if (!pItem)
+		return;
+	SourceFileInfo *pSourceFileInfo = pItem->sourceFileInfo();
+	if (pSourceFileInfo)	{
+		DialogMovie *pDialog = new DialogMovie (this);
+		pDialog->initMe (pSourceFileInfo, getMediaEngine(), m_pDVDAuthor->getDragNDropContainer()->sizeThumbnail.width());
+		pDialog->exec ();
+		*pSourceFileInfo = *pDialog->sourceFileInfo();
+		delete pDialog;
+		return;
+	}
+	
 	QStringList listFileTypes;
-	SourceFileEntry *pEntry = m_listSourceFileEntries[m_pSourceWidget->m_pListBoxAllSources->currentItem ()];
-	QString qsOriginalDisplayName = pEntry->qsDisplayName;
+	SourceFileEntry *pSourceFileEntry = getCurrentSourceFileEntry ();
+	if (!pSourceFileEntry)
+		return;
+
+//	QListViewItem *pItem = m_pListViewAllSources->currentItem ();
+//	int iCurrent = (int)( (float)pItem->itemPos() / (float)pItem->height());
+	int iCurrent = 0;
+	for (iCurrent=0;iCurrent<(int)m_listSourceFileEntries.count();iCurrent++)
+		if (m_listSourceFileEntries[iCurrent] == pSourceFileEntry)
+			break;
+
+	QString qsOriginalDisplayName = pSourceFileEntry->qsDisplayName;
 	listFileTypes.append (tr ("Movie/Image Files (+Movies+ *.bmp *.png *.jpg *.gif *.xbm)"));
 	listFileTypes.append (tr ("Movie Files (+Movies+)"));
 	listFileTypes.append (tr ("Image Files (*.bmp *.png *.jpg *.gif *.xbm)"));
@@ -379,23 +582,23 @@ void SourceToolBar::slotEditMovie()
 
 	// Here we try to find out if we have a movie or a sound ...
 	int iWhichTab = SOURCE_FILE_TAB;
-	int iCurrent = m_pSourceWidget->m_pListBoxAllSources->currentItem ();
-	if (	(iCurrent < (int)m_listSourceFileEntries.count ()) &&
-			(m_listSourceFileEntries[iCurrent]->bSoundSource) )
+//	if (	(iCurrent < (int)m_listSourceFileEntries.count ()) &&
+//			(m_listSourceFileEntries[iCurrent]->bSoundSource) )
+	if (pSourceFileEntry->bSoundSource)
 		iWhichTab = SOUND_OPTIONS_TAB;
 
 
-	DialogMovie *pDialog = new DialogMovie(m_pDVDAuthor->getXineEngine (), this, iWhichTab);
+	SourceFileDialog *pDialog = new SourceFileDialog(getMediaEngine (), this, iWhichTab);
 	pDialog->setFileTypes (listFileTypes);
-	pDialog->setSourceFileEntries(m_listSourceFileEntries,  m_pSourceWidget->m_pListBoxAllSources->currentItem ());
+	pDialog->setSourceFileEntries(m_listSourceFileEntries,  iCurrent);
 
 	int iReturn = pDialog->exec();
 	if (iReturn == QDialog::Rejected)
 		return;
 	refreshToolBarEntries();
 	// Here we check if the DisplayName has been changed. Note that the pointer has not changed, only the values.
-	if ( (qsOriginalDisplayName != pEntry->qsDisplayName) && (m_pDVDAuthor) )
-			m_pDVDAuthor->replaceSourceDisplayName(qsOriginalDisplayName, pEntry->qsDisplayName);
+	if ( (qsOriginalDisplayName != pSourceFileEntry->qsDisplayName) && (m_pDVDAuthor) )
+			m_pDVDAuthor->replaceSourceDisplayName(qsOriginalDisplayName, pSourceFileEntry->qsDisplayName);
 
 	delete pDialog;
 }
@@ -404,12 +607,11 @@ void SourceToolBar::refreshToolBarEntries()
 {
 	uint t, i;
 	QColor statusColor;
-	ListBoxColorText *pListBoxItem;
 	SourceFileEntry *pEntry;
 	SourceFileInfo *pInfo;
 	// This function will remove all entries from all listBox objects and re-create all information from
 	// The current m_listSourceFileEntries.
-	m_pSourceWidget->m_pListBoxAllSources->clear ();
+	m_pListViewAllSources  ->clear ();
 	m_pSourceWidget->m_pListViewVideoSources->clear ();
 	m_pSourceWidget->m_pListViewAudioSources->clear ();
 	for (t=0;t<m_listSourceFileEntries.count();t++)	{
@@ -441,82 +643,126 @@ void SourceToolBar::refreshToolBarEntries()
 					pInfo->qsSize,  pInfo->qsStatus, pInfo->qsFileName);
 			}
 		}
-		pListBoxItem = new ListBoxColorText (pEntry->qsDisplayName, statusColor);
-		m_pSourceWidget->m_pListBoxAllSources->insertItem(pListBoxItem);
+		new ListViewItemMedia (m_pListViewAllSources, pEntry, statusColor);
 	}
 }
 
-void SourceToolBar::slotConvertMovie()
-{
-	// Called when the user right clicks in the SourceFileEntry - list
-	QMessageBox::warning (NULL, tr ("Not implemented yet."),
-		tr ("This function is not implemented yet."), QMessageBox::Ok, QMessageBox::NoButton);
-}
-
 void SourceToolBar::slotDeleteSource()
 {
-	QString qsCurrentText = m_pSourceWidget->m_pListBoxAllSources->currentText();
+	QListViewItem *pItem = m_pListViewAllSources->currentItem();
+	if (!pItem)
+		return;
+
+	QString qsCurrentText = pItem->text(SOURCE_FILE_ENTRY_NAME);
+	// Okay now I added the total play time also to the filename, we should 
+	// disregard this from here ... E.g. "Title.mpg\n00:13:01"
+	int iPos = qsCurrentText.find ("\n");
+	qsCurrentText = qsCurrentText.left (iPos);
 	// Called when the user right clicks in the SourceFileEntry - list
-	if ( (!getCurrentSourceFileEntry()->bSoundSource) && (m_pDVDAuthor) )	{
-		
+	SourceFileEntry *pSourceFileEntry = getCurrentSourceFileEntry ();
+	if (!pSourceFileEntry)
+		return;
+
+	if ( (!pSourceFileEntry->bSoundSource) && (m_pDVDAuthor) )	{
 		// Okay we should politely check if this source is in use by a button.
-		if (m_pDVDAuthor->isSourceEntryUsed(qsCurrentText))
+		if (m_pDVDAuthor->isSourceEntryUsed(qsCurrentText))	{
 			if (QMessageBox::warning (NULL, tr ("Warning, This source is in use."),
 				tr ("This Source is in use.\nDo you realy want to delete this source ?\n"), 
 				QMessageBox::Yes, QMessageBox::No) == QMessageBox::No)
 					return;
+		}
 	}
-	
+
 	removeEntry (qsCurrentText, false);
 }
 
 void SourceToolBar::removeEntry (QString &qsEntry, bool bSourceOnly)
 {
 	uint t;
-	SourceFileEntry *pSourceFileEntry = NULL;
-	for (t=0;t<m_listSourceFileEntries.count();t++)	{
-		if (m_listSourceFileEntries[t]->qsDisplayName == qsEntry)	{
-			// Here we remove this entry from the m_listSourceFileEntris - list.
-			pSourceFileEntry = m_listSourceFileEntries[t];
-			m_listSourceFileEntries.remove (pSourceFileEntry);
-		}
-	}
-	for (t=0;t<m_pSourceWidget->m_pListBoxAllSources->count();t++)	{
-		if (m_pSourceWidget->m_pListBoxAllSources->text(t) == qsEntry)	{
-			// Here we remove this entry from m_pListBoxVideos - widget.
-			m_pSourceWidget->m_pListBoxAllSources->removeItem (t);
-		}
-	}
+	QFileInfo fileInfo;
+	SourceFileInfo  *pSourceFileInfo = NULL;
+	SourceFileEntry *pSourceFileEntry = getCurrentSourceFileEntry ();
 	if (!pSourceFileEntry)
 		return;
-	QValueList<QListViewItem *> listDelItems;
-	QListViewItem *pItem = m_pSourceWidget->m_pListViewVideoSources->firstChild();
-	while (pItem)	{
-		// Here we remove this entry from m_pListBoxVideos - widget.
+	// First we check if the user wants to remove a whole SourceFileEntry
+	if (pSourceFileEntry->qsDisplayName == qsEntry)	{
+		// Here we remove the full entry from the m_listSourceFileEntris - list.
+		removeEntry (pSourceFileEntry, bSourceOnly);
+		// At this point we can delete the pSourceFileEntry ...
+		delete pSourceFileEntry;
+	}
+	else {	// Okay here we check for the sourecFileInfo's ...
 		for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)	{
-			if (pItem->text(MOVIE_FILE_NAME_INDEX) == pSourceFileEntry->listFileInfos[t]->qsFileName)	{
+			pSourceFileInfo = pSourceFileEntry->listFileInfos[t];
+			fileInfo.setFile (pSourceFileInfo->qsFileName);
+			if (fileInfo.fileName() == qsEntry)	{
+				pSourceFileEntry->listFileInfos.remove (pSourceFileInfo);
+				delete pSourceFileInfo;
+				refreshToolBarEntries ();
+				// Check if we have just removed the last source from this entry.
+				if (pSourceFileEntry->listFileInfos.count () < 1)	{
+					// in which case we want to alos delete the header ...
+					removeEntry (pSourceFileEntry, bSourceOnly);
+					delete pSourceFileEntry;
+				}
+			}
+		}
+	}
+}
+
+void SourceToolBar::removeEntry (SourceFileEntry *pSourceFileEntry, bool bSourceOnly)
+{
+	// This function is also called from UndoObjects.
+	uint t;
+	QStringList listFileNames;
+	if (!pSourceFileEntry)
+		return;
+	m_listSourceFileEntries.remove (pSourceFileEntry);
+	// Next we remove the entry from the AllSources - Tab
+	QValueList<QListViewItem *> listDelItems;
+	QListViewItem *pItem = m_pListViewAllSources->firstChild();
+	for (t=0;t<(uint)m_pListViewAllSources->childCount();t++)	{
+		if (pItem->text(SOURCE_FILE_ENTRY_NAME) == pSourceFileEntry->qsDisplayName)	{
+			// Here we remove this entry from m_pListViewAllSources - widget.
+			listDelItems.append (pItem);
+		}
+		pItem = pItem->nextSibling();
+	}
+	for (t=0;t<listDelItems.count();t++)
+		delete listDelItems[t];
+	listDelItems.clear();
+
+	// we ceate here a temp list of all file names ...
+	for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)
+		listFileNames.append(pSourceFileEntry->listFileInfos[t]->qsFileName);
+
+	pItem = m_pSourceWidget->m_pListViewVideoSources->firstChild();
+	while (pItem)	{
+		// Here we remove this entry from m_pListViewVideos - widget.
+		for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)	{
+			if (pItem->text(MOVIE_FILE_NAME_INDEX) == listFileNames[t])	{
 				listDelItems.append(pItem);
 				// FIXME: If we use SourceFileEntry->qsDisplay name rather then the single filename, we are better off here
 				//        Since we remove only the associated files and leave the others untouched.
 				// Okay if the user has the same file multiple times in there we only want to remove the entry once.
-				pSourceFileEntry->listFileInfos[t]->qsFileName = QString ("");
+				listFileNames[t] = QString ("");
 			}
 		}
 		pItem = pItem->nextSibling();
 	}
 	// And here we delete the items
-	for (t=0;t<listDelItems.count();t++)	{
+	for (t=0;t<listDelItems.count();t++)
 		delete listDelItems[t];
-	}
 	listDelItems.clear();
+
 	pItem = m_pSourceWidget->m_pListViewAudioSources->firstChild();
 	while (pItem)	{
-		// Here we remove this entry from m_pListBoxVideos - widget.
+		// Here we remove this entry from m_pListViewAudio - widget.
 		for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)	{
-			if (pItem->text(AUDIO_FILE_NAME_INDEX) == pSourceFileEntry->listFileInfos[t]->qsFileName)	{
+			if (pItem->text(AUDIO_FILE_NAME_INDEX) == listFileNames[t])	{
 				listDelItems.append(pItem);
 				// Okay if the user has the same file multiple times in there we only want to remove the entry once.
-				pSourceFileEntry->listFileInfos[t]->qsFileName = QString ("");
+				listFileNames[t] = QString ("");
 			}
 		}
 		pItem = pItem->nextSibling();
@@ -530,47 +776,50 @@ void SourceToolBar::removeEntry (QString &qsEntry, bool bSourceOnly)
 		// So the user has decided to delete this source, then we should change the assoziated
 		// buttons - action !!!
 		m_pDVDAuthor->removedSourceEntry(pSourceFileEntry);
-
-	// At this point we can delete the pSourceFileEntry ...
-	delete pSourceFileEntry;
 }
 
-
 void SourceToolBar::slotPlayMovie()
 {
 	// Called when the user right clicks in the SourceFileEntry - list
-	uint t, i;
-	for (t=0;t<m_listSourceFileEntries.count();t++)	{
-		if (m_pSourceWidget->m_pListBoxAllSources->currentText() == m_listSourceFileEntries[t]->qsDisplayName)	{
-			// Here we execute the external QXine video viewer application ...
-			
-			// First let us find out if the application exists after all ...
-//			QFileInfo fileInfo("qplayer");
-//			if (!fileInfo.exists ())
-//				QMessageBox::warning (NULL, QString ("Error.."),
-//					QString ("Could not find qplayer application."), QMessageBox::Ok, QMessageBox::Ok);
-//			else
-//				QMessageBox::warning (NULL, QString ("Cool .."),
-//					QString ("Stuhl ...."), QMessageBox::Ok, QMessageBox::Ok);
-					
-			QString qsCommand ("qplayer ");
-			for (i=0;i<m_listSourceFileEntries[t]->listFileInfos.count();i++)
-				qsCommand += QString ("\"%1\" ").arg(m_listSourceFileEntries[t]->listFileInfos[i]->qsFileName);
-			qsCommand += QString (" &");
-			system ((const char *)qsCommand);
-			// Finally leave the loop.
-			break;
-		}
+	uint i;
+	QString qsCommand = QString ("%1 ").arg(Global::qsExternalPlayer);
+	SourceFileEntry *pSourceFileEntry = NULL;
+	SourceFileInfo  *pSourceFileInfo  = NULL;
+
+	ListViewItemMedia *pItem = (ListViewItemMedia *)m_pListViewAllSources->currentItem();
+	if (!pItem)
+		return;
+	pSourceFileEntry = pItem->sourceFileEntry ();
+	pSourceFileInfo  = pItem->sourceFileInfo  ();
+	if (pSourceFileEntry)	{
+		for (i=0;i<pSourceFileEntry->listFileInfos.count();i++)
+			qsCommand += QString ("\"%1\" ").arg(pSourceFileEntry->listFileInfos[i]->qsFileName);
 	}
+	else	{
+		if (!pSourceFileInfo)	// This should never happen but to make sure ...
+			return;
+		qsCommand += QString ("\"%1\" ").arg(pSourceFileInfo->qsFileName);
+	}
+	// Here we execute the external QXine video viewer application ...
+	qsCommand += QString (" &");
+	system ((const char *)qsCommand);
 }
 
 // the following two functions are called from CSlideDialog, if avail ...
 void SourceToolBar::slotAddSlideshow (QString qsSlideshowName)
 {
 printf ("SourceToolBar::slotAddSlideshow <%s>\n", (const char *)qsSlideshowName);
+	if (!m_pDVDAuthor->checkForNewProject ())
+		return;
+
 	// Lets create a new SourceFileEntry ...
 	SourceFileEntry *pEntry = new SourceFileEntry;
 	SourceFileInfo  *pInfo = new SourceFileInfo;
+	// Here we create the temp image
+	pEntry->sizeThumbnail = m_pDVDAuthor->getDragNDropContainer()->sizeThumbnail;
+	pInfo->pPreview = new QImage (QImage::fromMimeSource( "create_slideshow.jpg" ));
+	*pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
+
 	pEntry->bIsSlideshow = true;
 	pInfo->qsFileName = qsSlideshowName;
 	pEntry->listFileInfos.append(pInfo);
@@ -578,20 +827,22 @@ printf ("SourceToolBar::slotAddSlideshow <%s>\n", (const char *)qsSlideshowName)
 //	pEntry->qsDisplayName = qsSlideshowName;	// E.g. slideshow.xml
 	m_listSourceFileEntries.append(pEntry);
 	// Okay, now we should also add this into the list box ...
-	ListBoxColorText *pListBoxItem = new ListBoxColorText (pEntry->qsDisplayName, QColor (COLOR_SLIDE_FILES_OK));
-	m_pSourceWidget->m_pListBoxAllSources->insertItem(pListBoxItem);
+	new ListViewItemMedia (m_pListViewAllSources, pEntry, QColor (COLOR_SLIDE_FILES_OK));
 }
 
 void SourceToolBar::slotSlideshowDone(QString qsSlideshowName)
 {
+	Utils theUtil;
 printf ("SourceToolBar::slotSlideshowDone <%s>\n", (const char *) qsSlideshowName);
 	uint t, iListBoxPosition = 0;
 	SourceFileEntry *pEntry;
-	for (t=0;t <m_pSourceWidget->m_pListBoxAllSources->count();t++)	{
-		if (m_pSourceWidget->m_pListBoxAllSources->text(t) == qsSlideshowName)	{
+	QListViewItem *pItem = m_pListViewAllSources->firstChild();
+	for (t=0;t <(uint)m_pListViewAllSources->childCount();t++)	{
+		if (pItem->text(SOURCE_FILE_ENTRY_NAME) == qsSlideshowName)	{
 			iListBoxPosition = t;
 			break;
 		}
+		pItem = pItem->nextSibling();
 	}	
 	for (t=0;t<m_listSourceFileEntries.count();t++)	{
 		pEntry = m_listSourceFileEntries[t];
@@ -600,13 +851,11 @@ printf ("SourceToolBar::slotSlideshowDone <%s>\n", (const char *) qsSlideshowNam
 			pEntry->qsDisplayName = qsSlideshowName + QString (".mpeg");
 			// Next we determine the fileName of the generated mpeg video ...
 			QFileInfo fileInfo (pEntry->listFileInfos[0]->qsFileName);
-			pEntry->listFileInfos[0]->qsFileName = m_pDVDAuthor->getTempFile(fileInfo.fileName()+QString (".mpeg"));
+			pEntry->listFileInfos[0]->qsFileName = theUtil.getTempFile(fileInfo.fileName()+QString (".mpeg"));
 			pEntry->bIsSlideshow = false;	// now we hold a mpeg and not a xml - file ...
 			pEntry->bSoundSource = false;
 
-			ListBoxColorText *pListBoxItem = new ListBoxColorText (pEntry->qsDisplayName, QColor (COLOR_MOVIE_FILES_OK));
-			m_pSourceWidget->m_pListBoxAllSources->changeItem (pListBoxItem, iListBoxPosition);
-//			m_pListBoxVideos->insertItem(pListBoxItem);
+			new ListViewItemMedia (m_pListViewAllSources, pEntry,QColor (COLOR_MOVIE_FILES_OK));
 			return;
 		}
 	}
@@ -619,7 +868,7 @@ void SourceToolBar::clear ()
 		delete m_listSourceFileEntries[t];
 	m_listSourceFileEntries.clear();
 
-	m_pSourceWidget->m_pListBoxAllSources->clear();
+	m_pListViewAllSources  ->clear();
 	m_pSourceWidget->m_pListViewVideoSources->clear();
 	m_pSourceWidget->m_pListViewAudioSources->clear();
 }
