@@ -30,10 +30,13 @@
 #define MOVIE_FILE_NAME_INDEX 7
 #define AUDIO_FILE_NAME_INDEX 7
 
+#include <qthread.h>
+
 #include "uisourcewidget.h"
 #include "sourcefileentry.h"
 
 class QDVDAuthor;
+class MediaInfo;
 
 class SourceToolBar : public QToolBar
 {
@@ -43,40 +46,53 @@ public:
 	 SourceToolBar (const QString &, QMainWindow *, QWidget *, bool b=FALSE, const char *n=0, WFlags f=0);
 	~SourceToolBar ();
 
-//	void addMovie (QString &);
-	void addMovie (SourceFileEntry *);
-	void addSound (QStringList &);
-	void clear ();
+	void addMovie     (SourceFileEntry *);
+	void addMovieList (QStringList &, QString *p=NULL);
+	void addSound     (QStringList &);
+	void clear        ();
 	
 	int sourceFileCount();
 	SourceFileEntry *sourceFileEntry(uint);
 	SourceFileEntry *getCurrentSourceFileEntry();
+	SourceFileInfo  *getCurrentSourceFileInfo ();
 	void appendSourceFileEntry(SourceFileEntry *);
 	void removeEntry (QString &, bool b=true);
+	void removeEntry (SourceFileEntry *, bool b=true);
+	int  getFreeSourceSlot       ();
 
 	virtual QSize sizeHint () const;
 	QString convertFileSize(uint);
 
+	MediaInfo *getMediaInfo ();
+
+protected:
+	virtual void  timerEvent      (QTimerEvent *);
+
 private:
-	void refreshToolBarEntries ();
-	int getFreeSourceSlot ();
+	void  refreshToolBarEntries   ();
+	void *getMediaEngine          ();
+//	void  makeScreenshots         (SourceFileEntry *);
 
 public slots:
-	virtual void slotClickedOnVideoList(int, QListBoxItem *, const QPoint &);
-	virtual void slotEditMovie();
-	virtual void slotConvertMovie();
-	virtual void slotDeleteSource();
-	virtual void slotPlayMovie();
+	virtual void slotDoubleClickedOnVideoList(QListViewItem *, const QPoint &, int);
+	virtual void slotRightClickedOnVideoList (QListViewItem *, const QPoint &, int);
+	virtual void slotClickedOnVideoList      (QListViewItem *, const QPoint &, int);
+	virtual void slotPlayMovie    ();
+	virtual void slotEditMovie    ();
+	virtual void slotDeleteSource ();
 
-	virtual void slotAddMovie ();
-	virtual void slotAddSound ();
+	virtual void slotAddMovie     ();
+	virtual void slotAddSound     ();
 	virtual void slotAddSlideshow ();
 	virtual void slotAddSlideshow (QString);
 	virtual void slotSlideshowDone(QString);
+	virtual void slotRemoveEntry  (SourceFileEntry *);
 
 private:
-	uiSourceWidget *m_pSourceWidget;
-	QDVDAuthor     *m_pDVDAuthor;
+	uiSourceWidget    *m_pSourceWidget;
+	MediaInfo         *m_pMediaInfo;
+	QDVDAuthor        *m_pDVDAuthor;
+	QListView         *m_pListViewAllSources;
 	QValueList<SourceFileEntry *>	m_listSourceFileEntries;
 };
 
