@@ -12,6 +12,7 @@
 
 #include <qpen.h>
 #include <qfont.h>
+#include <qimage.h>
 #include <qpainter.h>
 #include <qpopupmenu.h>
 #include <qlistview.h>
@@ -28,12 +29,17 @@
 TextObject::TextObject (QWidget *pParent)
 	: MenuObject (pParent)
 {
-	m_qsObjectType = QString (TEXT_OBJECT);
+	m_qsObjectType    = QString (TEXT_OBJECT);
 	m_colorBackground = QColor(TRANSPARENT_COLOR);	// indicate the transparent color.
+	m_iStyleStrategy  = QFont::PreferAntialias;
+	m_pContextMenu    = NULL;
 }
 
 TextObject::~TextObject ()
 {
+	if (m_pContextMenu)
+		delete m_pContextMenu;
+	m_pContextMenu = NULL;
 }
 
 void TextObject::setFont (QFont &theFont)
@@ -49,6 +55,7 @@ QFont &TextObject::getFont ()
 void TextObject::setText (QString &theText)
 {
 	m_qsText = theText;
+	setName (theText);
 }
 
 QString &TextObject::getText ()
@@ -66,6 +73,12 @@ QPoint &TextObject::getTextAlign ()
 	return m_ptTextAlign;
 }
 
+void TextObject::setStyleStrategy (int iStyleStrategy)
+{
+	m_iStyleStrategy = iStyleStrategy;
+	m_Font.setStyleStrategy ((QFont::StyleStrategy)iStyleStrategy);
+}
+
 void TextObject::replaceColor (QColor theColor, QColor oldColor)
 {
 	if (getForegroundColor () == oldColor)
@@ -94,10 +107,119 @@ QColor &TextObject::getBackgroundColor ()
 	return m_colorBackground;
 }
 
+void TextObject::drawSemiTransparent (QPainter *pPainter)
+{
+	QWMatrix theMatrix;
+	QRect dummyRect, theRect;
+	int iFlags, x, y;
+	int iSourceHeight, iSourceWidth, iSourceStartX, iSourceStartY, iTargetStartX, iTargetStartY;
+	QColor sourceColor, targetColor, theColor;
+	QRgb sourcePixel, targetPixel;
+	QImage sourceImg, targetImg;
+	float fTargetTrans, fSourceTrans;
+
+	// init variables ...
+	fTargetTrans = 1.0 - modifiers()->fTransparency;
+	fSourceTrans = modifiers()->fTransparency;
+
+	QPen thePen (m_colorForeground, 2, Qt::DashDotLine);
+	// Here we define the cenetered rect.
+	theRect = QRect((int)-(rect().width()/ 2.0), (int)-(rect().height()/2.0), rect().width(), rect().height());
+
+	// First we translate to the center of the rect.
+	theMatrix.translate (
+		(double)rect().x() + (int)(rect().width () / 2.0), 
+		(double)rect().y() + (int)(rect().height() / 2.0));
+	//. then we apply the other modifications ...
+	theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
+	theMatrix.rotate (modifiers()->fRotate);
+	theMatrix.shear  (modifiers()->fShearX, modifiers()->fShearY);
+	// Here we get the rect that encompasses the button for this object.
+	m_boundingRect = theMatrix.mapRect(theRect);
+	// And for the source we need to set the right matrix.
+	theMatrix.reset  ();
+	theMatrix.translate ((double)m_boundingRect.width()/2.0, (double)m_boundingRect.height()/2.0);
+	theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
+	theMatrix.rotate (modifiers()->fRotate);
+	theMatrix.shear  (modifiers()->fShearX, modifiers()->fShearY);
+
+	QPixmap thePixmap = QPixmap(m_boundingRect.size());
+	if (thePixmap.isNull())
+		return;
+
+	thePixmap.fill (QColor (TRANSPARENT_COLOR));
+	QPainter pmPainter (&thePixmap);
+	//  then we actually set the world matrix 
+	pmPainter.setWorldMatrix(theMatrix);
+
+	pmPainter.setPen(Qt::NoPen);
+	pmPainter.setBrush (QBrush(m_colorBackground));
+	pmPainter.drawRect(theRect);
+ 
+	m_Font.setStyleStrategy ((QFont::StyleStrategy)m_iStyleStrategy);
+	pmPainter.setFont(m_Font);
+
+	// Okay, I abused a QPoint class to hold some other infos ... so what ???
+	iFlags = Qt::DontClip|Qt::WordBreak|m_ptTextAlign.x()|m_ptTextAlign.y();
+
+	pmPainter.drawText(theRect, iFlags, m_qsText, -1, &dummyRect);
+	
+	// At this point we should have the text on a memory Bitmap object, and now 
+	// we should copy this over, bit for bit. 
+	iSourceHeight = thePixmap.height(); 
+	iSourceWidth  = thePixmap.width ();
+	iSourceStartX = 0;
+	iSourceStartY = 0;
+	iTargetStartX = pPainter->viewport().x() + m_boundingRect.x();
+	iTargetStartY = pPainter->viewport().y() + m_boundingRect.y();
+
+	// First we need to create a Pixmap which holds the Target pixels
+	QPaintDevice *pPDPainter = pPainter->device();
+	if (pPDPainter == 0)
+		return;
+
+	sourceImg = thePixmap.convertToImage();
+
+	QPixmap *pPixmap = new QPixmap(iSourceWidth, iSourceHeight);
+	if ( ! pPixmap )
+		return;
+	bitBlt (pPixmap, 0, 0, pPainter->device(), 
+		iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight, Qt::CopyROP, true);
+		// To get Pixel information we need a QImage however ...
+	targetImg = pPixmap->convertToImage();
+	delete pPixmap;
+
+	iTargetStartX -= pPainter->viewport().x();
+	iTargetStartY -= pPainter->viewport().y();
+	for (y=0; y < iSourceHeight; y++)	{
+		for (x=0; x < iSourceWidth; x++)	{
+			sourcePixel = sourceImg.pixel(x, y );	// calculate the mix of background and foreground.
+			sourcePixel &= 0x00ffffff;// filter out the transparency part of the color
+			if (sourcePixel != 0x00FFFFFF)	{	// And check if this is a pixel we 
+				targetPixel = targetImg.pixel(x, y);
+				targetPixel &= 0x00ffffff;	// filter out the transparency part of the color
+				targetColor = QColor ( targetPixel );
+				sourceColor = QColor ( sourcePixel );
+				theColor    = QColor (
+					(int)(fSourceTrans * sourceColor.red()   + (int)(fTargetTrans * targetColor.red())),
+					(int)(fSourceTrans * sourceColor.green() + (int)(fTargetTrans * targetColor.green())),
+					(int)(fSourceTrans * sourceColor.blue()  + (int)(fTargetTrans * targetColor.blue()))
+				);
+				pPainter->setPen ( theColor );
+				pPainter->drawPoint(x+iTargetStartX, y+iTargetStartY);
+			}
+		}
+	}
+}
 
 void TextObject::drawContents (QPainter *painter)
 {
 	QWMatrix theMatrix;// = matrix();
+	// If we have a complete transparent text we should not draw at all.
+	if (modifiers()->fTransparency == 1.0)
+		return;
+	else if ( (modifiers()->fTransparency != 0.0) && ( ! m_bDrawRect) )
+		return drawSemiTransparent (painter);
 	// Here we calculate the center point of gravity (rotation)
 	QPoint centerPos;
 	centerPos.setX (rect().x() + (int)(rect().width () / 2.0));
@@ -141,7 +263,7 @@ void TextObject::drawContents (QPainter *painter)
 	else
 		painter->setBrush(Qt::NoBrush);
  
-	m_Font.setStyleStrategy (QFont::NoAntialias);
+	m_Font.setStyleStrategy ((QFont::StyleStrategy)m_iStyleStrategy);
 	painter->setFont(m_Font);
 	QRect boundingRect;
 
@@ -167,75 +289,16 @@ void TextObject::drawContents (QPainter *painter)
 	painter->setWorldMatrix(theMatrix);
 }
 
-/*
 
-void TextObject::drawContents (QPainter *painter)
+void TextObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int)
 {
-	QWMatrix theMatrix;// = matrix();
-	// Here we calculate the center point of gravity (rotation)
-	QPoint centerPos;
-	centerPos.setX (rect().x() + (int)(rect().width () / 2.0));
-	centerPos.setY (rect().y() + (int)(rect().height() / 2.0));
-	// Here we define the cenetered rect.
-	QRect theRect ((int)-(rect().width()/ 2.0), (int)-(rect().height()/2.0), rect().width(), rect().height());
+	// Next is to set the AnimationAttributes
+	for (uint t=0;t<m_listAnimationAttributes.count();t++)
+		m_listAnimationAttributes[t]->setValue (iRenderFrameNumber);
 
-	// From the Qt documentation ...
-	// This transformation engine is a three-step pipeline
-	// The first step uses the world transformation matrix.
-	// The second step uses the window.
-	// The third step uses the viewport.
-
-	// First we translate to the appropriate location,
-	theMatrix.translate ((double)centerPos.x(), (double)centerPos.y());
-
-	//. then we apply the other modifications ...
-	theMatrix.scale  (modifiers()->fScaleX, modifiers()->fScaleY);
-	theMatrix.rotate (modifiers()->fRotate);
-	theMatrix.shear  (modifiers()->fShearX, modifiers()->fShearY);
-	painter->setWorldMatrix(theMatrix);
-	// Here we get the rect that encompasses the button for this object.
-	m_boundingRect = theMatrix.mapRect(theRect);
-
-	QPen thePen (m_colorForeground, 2, Qt::DashDotLine);
-	if (m_colorBackground != QColor(TRANSPARENT_COLOR))	{
-		painter->setPen(Qt::NoPen);
-		painter->setBrush (QBrush(m_colorBackground));
-		painter->drawRect(theRect);
-	}
-	else
-		painter->setBrush(Qt::NoBrush);
-
-	painter->setPen(thePen);
-	painter->setFont(m_Font);
-	QRect boundingRect;
-
-	int iFlags = Qt::DontClip|Qt::WordBreak|m_ptTextAlign.x()|m_ptTextAlign.y();
-
-	if (m_bDrawRect)
-		painter->drawRect(theRect);
-
-	painter->drawText(theRect, iFlags, m_qsText, -1, &boundingRect);
-
-	if (m_rect.width()  < boundingRect.width())	{
-		m_rect.setWidth  (boundingRect.width());
-		m_pParent->update ();
-	}
-	if (m_rect.height() < boundingRect.height())	{
-		m_rect.setHeight (boundingRect.height());
-		m_pParent->update ();
-	}
-	// Here we re-set the world matrix and translate the newly drawn ... thing ...
-	theMatrix.reset();
-	painter->setWorldMatrix(theMatrix);
-	// for now to see what is going on ...
-	painter->setBrush(Qt::NoBrush);
-	painter->setPen(thePen);
-	if (m_bDrawRect)
-		painter->drawRect(m_boundingRect);
+	drawContents (pPainter);
 }
 
-*/
-
 bool TextObject::readProjectFile  (QDomNode &theNode)
 {
 	QDomElement theElement = theNode.toElement();
@@ -367,21 +430,36 @@ bool TextObject::mousePressEvent (QMouseEvent *pEvent)
 {
 	m_currentMousePos = pEvent->pos();
 	if (pEvent->button() == Qt::RightButton)	{
-		QPopupMenu *pMenu = new QPopupMenu(m_pParent);
-		pMenu->insertItem ( tr ("Edit ...")  , this, SLOT(slotEdit()));
-		pMenu->insertItem ( tr ("Matrix ..."), this, SLOT(slotMatrix()));
-		pMenu->insertItem ( tr ("Delete")    , this, SLOT(slotDelete()));
-		pMenu->insertSeparator();
-		pMenu->insertItem ( tr ("Add Frame"), this, SLOT(slotAddFrame()));
-		pMenu->insertItem ( tr ("Add Image"), this, SLOT(slotAddImage()));
-		pMenu->insertItem ( tr ("Add Movie"), this, SLOT(slotAddMovie()));
-		pMenu->insertSeparator();
-		pMenu->insertItem ( tr ("Define as Button") , this, SLOT(slotDefineAsButton()));
-		int iReturn = pMenu->exec(pEvent->globalPos());
+		QPoint globalPos = pEvent->globalPos();
+
+		QPopupMenu *pStackMenu = new QPopupMenu(m_pParent);
+		pStackMenu->insertItem ( tr ("To Front")  , this, SLOT(slotToFront()));
+		pStackMenu->insertItem ( tr ("To Back")   , this, SLOT(slotToBack()));
+		globalPos.setX (globalPos.x() - pStackMenu->sizeHint().width()); // -100);
+		pStackMenu->popup(globalPos, 1);
+
+		if (m_pContextMenu)
+			delete m_pContextMenu;
+		m_pContextMenu = new QPopupMenu(m_pParent);
+		m_pContextMenu->insertItem ( tr ("Edit ...")  , this,  SLOT(slotEdit()));
+		m_pContextMenu->insertItem ( tr ("Matrix ..."), this,  SLOT(slotMatrix()));
+		m_pContextMenu->insertItem ( tr ("Delete")    , this,  SLOT(slotDelete()));
+		m_pContextMenu->insertSeparator();
+		m_pContextMenu->insertItem ( tr ("Add Frame"), this,   SLOT(slotAddFrame()));
+		m_pContextMenu->insertItem ( tr ("Add Image"), this,   SLOT(slotAddImage()));
+		m_pContextMenu->insertItem ( tr ("Add Movie"), this,   SLOT(slotAddMovie()));
+		m_pContextMenu->insertSeparator();
+		m_pContextMenu->insertItem ( tr ("Define as Button") , this, SLOT(slotDefineAsButton()));
+		// Blocking call
+		m_pContextMenu->exec(pEvent->globalPos(), 3);
 		// Here we mark that the user called a menu item thus we don't want the
 		// base classes to continue with the mouse event
-		if (iReturn != -1)
-			return true;
+		delete pStackMenu;
+		// Note the menu might have been already deleted in slotToFront/slotToBack
+		if (m_pContextMenu)
+			delete m_pContextMenu;
+		m_pContextMenu = NULL;
+		return true;
 	}
 	else
 		m_bDrawRect = true;
@@ -405,13 +483,16 @@ bool TextObject::mouseDoubleClickEvent (QMouseEvent *)
 	fontDialog.setTextAlign (getTextAlign());
 	fontDialog.setBackgroundColor (getBackgroundColor());
 	fontDialog.setForegroundColor (getForegroundColor());
-
+	fontDialog.setTransparency (modifiers()->fTransparency);
+	fontDialog.setAnimation ( animation () );
+	fontDialog.setRect (rect());	// setRect (boundingRect());
 	if (fontDialog.exec() == QDialog::Rejected)
 		return false;
 
 	setFont(fontDialog.getFont());
 	QString theString = fontDialog.getText();
 	setText(theString);
+	setAnimation (fontDialog.getAnimation ());
 	if (fontDialog.getBackgroundColor() != getBackgroundColor())	{
 		// This emit signal is only caught when in ButtonDialog and the Selected, or Highlighted mask 
 		// was changed (I.e. This Object is in one of those two frames).
@@ -428,11 +509,14 @@ bool TextObject::mouseDoubleClickEvent (QMouseEvent *)
 		// P.s. replaceColor (QColor, QColor) of all ButtonObjects will be called, inclusive this object)
 	}
 	setForegroundColor (fontDialog.getForegroundColor());
+	modifiers()->fTransparency = fontDialog.getTransparency();
 	setTextAlign(fontDialog.getTextAlign());
 	if (fontDialog.getFit())	{
 		rect().setWidth (1);
 		rect().setHeight(1);
 	}
+	else
+		setRect(fontDialog.getRect());
 
 	m_pParent->update ();
 	emit (signalUpdatePixmap());
@@ -452,11 +536,6 @@ void TextObject::slotMatrix()
 	pDialog->show();
 }
 
-void TextObject::slotDelete ()
-{
-	emit (signalDeleteMe(this));
-}
-
 void TextObject::slotAddFrame ()
 {
 	QMessageBox::warning (NULL, tr ("Not Implemented yet."), tr ("Not Implemented yet."),
@@ -491,6 +570,8 @@ MenuObject *TextObject::clone()
 	pNewObject->setTextAlign (getTextAlign());
 	pNewObject->setForegroundColor (getForegroundColor());
 	pNewObject->setBackgroundColor (getBackgroundColor());
+	pNewObject->setStyleStrategy   ((QFont::StyleStrategy)m_iStyleStrategy);
+
 	// The following two are not really needed, since we get those 
 	// informations solely from the Normal State - objects ...
 	pNewObject->setRect(rect());
@@ -499,3 +580,47 @@ MenuObject *TextObject::clone()
 	return pNewObject;
 }
 
+#include <qfont.h>
+AnimationAttribute *TextObject::getSpecificAttributes (long iMaxNumberOfFrames, QString qsProperty)
+{
+//	QFont       m_Font;
+//	QPoint      m_ptTextAlign;
+
+	AnimationAttribute *pAnimAttr = NULL;
+	static int m_iTestInt = 0;
+
+	if (qsProperty == "text")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_qsText, &m_qsText);
+	else if (qsProperty == "font")	{
+		FunctionCallback<QFont> *callMeBack = new FunctionCallback<QFont>(m_Font, &QFont::fromString);
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_Font.toString(), callMeBack);
+	}
+	else if (qsProperty == "textAlign")
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_iTestInt, &m_iTestInt);
+	else if (qsProperty == "foregroundColor.red")	{
+		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorForeground, TYPE_COLOR_RED);
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorForeground.red(), callMeBack);
+	}
+	else if (qsProperty == "foregroundColor.green")	{
+		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorForeground, TYPE_COLOR_GREEN);
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorForeground.green(), callMeBack);
+	}
+	else if (qsProperty == "foregroundColor.blue")	{
+		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorForeground, TYPE_COLOR_BLUE);
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorForeground.blue(), callMeBack);
+	}
+	else if (qsProperty == "backgroundColor.red")	{
+		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorBackground, TYPE_COLOR_RED);
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorBackground.red(), callMeBack);
+	}
+	else if (qsProperty == "backgroundColor.green")	{
+		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorBackground, TYPE_COLOR_GREEN);
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorBackground.green(), callMeBack);
+	}
+	else if (qsProperty == "backgroundColor.blue")	{
+		FunctionCallback<QColor> *callMeBack = new FunctionCallback<QColor>(m_colorBackground, TYPE_COLOR_BLUE);
+		pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_colorBackground.blue(), callMeBack);
+	}
+	return pAnimAttr;
+}
+
