@@ -58,7 +58,10 @@ bool CXmlDVDAuthor::readXml ()
 	}
 	// And at last lets try to read the information of the file.
 	QDomElement docElem = xmlDoc.documentElement();
-	return m_dvdauthor.readXml (&docElem);
+	bool bReturn = m_dvdauthor.readXml (&docElem);
+
+	projectFile.close();
+	return bReturn;
 }
 
 bool CXmlDVDAuthor::dvdauthor_struct::readXml(QDomElement *pDocElem)
@@ -92,6 +95,7 @@ bool CXmlDVDAuthor::dvdauthor_struct::readXml(QDomElement *pDocElem)
 		// Otherwise go to the next node ...
 		xmlNode = xmlNode.nextSibling();
 	}
+	delete pTempTitleset;
 	return true;
 }
 
